# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.host import ConfigSpec

from pyVmomi.vim.profile import ApplyProfile
from pyVmomi.vim.profile import DeferredPolicyOptionParameter
from pyVmomi.vim.profile import Profile
from pyVmomi.vim.profile import ProfileMetadata
from pyVmomi.vim.profile import ProfileStructure

from pyVmomi.vim.profile.host import AnswerFile
from pyVmomi.vim.profile.host import AnswerFileStatusResult
from pyVmomi.vim.profile.host import ExecuteResult
from pyVmomi.vim.profile.host import HostApplyProfile

class ProfileManager(ProfileManager):
   class TaskListRequirement(Enum):
      maintenanceModeRequired: ClassVar['TaskListRequirement'] = 'maintenanceModeRequired'
      rebootRequired: ClassVar['TaskListRequirement'] = 'rebootRequired'

   class ConfigTaskList(DynamicData):
      configSpec: Optional[ConfigSpec] = None
      taskDescription: list[LocalizableMessage] = []
      taskListRequirement: list[str] = []

   class AnswerFileCreateSpec(DynamicData):
      validating: Optional[bool] = None

   class AnswerFileOptionsCreateSpec(AnswerFileCreateSpec):
      userInput: list[DeferredPolicyOptionParameter] = []

   class AnswerFileSerializedCreateSpec(AnswerFileCreateSpec):
      answerFileConfigString: str

   class AnswerFileStatus(Enum):
      valid: ClassVar['AnswerFileStatus'] = 'valid'
      invalid: ClassVar['AnswerFileStatus'] = 'invalid'
      unknown: ClassVar['AnswerFileStatus'] = 'unknown'

   class EntityCustomizations(DynamicData):
      pass

   class StructuredCustomizations(EntityCustomizations):
      entity: ManagedEntity
      customizations: Optional[AnswerFile] = None

   class HostToConfigSpecMap(DynamicData):
      host: HostSystem
      configSpec: AnswerFileCreateSpec

   class ApplyHostConfigSpec(ExecuteResult):
      host: HostSystem
      taskListRequirement: list[str] = []
      taskDescription: list[LocalizableMessage] = []
      rebootStateless: Optional[bool] = None
      rebootHost: Optional[bool] = None
      faultData: Optional[MethodFault] = None

   class ApplyHostConfigResult(DynamicData):
      class Status(Enum):
         success: ClassVar['Status'] = 'success'
         failed: ClassVar['Status'] = 'failed'
         reboot_failed: ClassVar['Status'] = 'reboot_failed'
         stateless_reboot_failed: ClassVar['Status'] = 'stateless_reboot_failed'
         check_compliance_failed: ClassVar['Status'] = 'check_compliance_failed'
         state_not_satisfied: ClassVar['Status'] = 'state_not_satisfied'
         exit_maintenancemode_failed: ClassVar['Status'] = 'exit_maintenancemode_failed'
         canceled: ClassVar['Status'] = 'canceled'

      startTime: datetime
      completeTime: datetime
      host: HostSystem
      status: str
      errors: list[MethodFault] = []

   class CompositionValidationResult(DynamicData):
      class ResultElement(DynamicData):
         class Status(Enum):
            success: ClassVar['Status'] = 'success'
            error: ClassVar['Status'] = 'error'

         target: Profile
         status: str
         errors: list[LocalizableMessage] = []
         sourceDiffForToBeMerged: Optional[HostApplyProfile] = None
         targetDiffForToBeMerged: Optional[HostApplyProfile] = None
         toBeAdded: Optional[HostApplyProfile] = None
         toBeDeleted: Optional[HostApplyProfile] = None
         toBeDisabled: Optional[HostApplyProfile] = None
         toBeEnabled: Optional[HostApplyProfile] = None
         toBeReenableCC: Optional[HostApplyProfile] = None

      results: list[ResultElement] = []
      errors: list[LocalizableMessage] = []

   class CompositionResult(DynamicData):
      class ResultElement(DynamicData):
         class Status(Enum):
            success: ClassVar['Status'] = 'success'
            error: ClassVar['Status'] = 'error'

         target: Profile
         status: str
         errors: list[LocalizableMessage] = []

      errors: list[LocalizableMessage] = []
      results: list[ResultElement] = []

   def ApplyHostConfiguration(self, host: HostSystem, configSpec: ConfigSpec, userInput: list[DeferredPolicyOptionParameter]) -> Task: ...
   def GenerateConfigTaskList(self, configSpec: ConfigSpec, host: HostSystem) -> ConfigTaskList: ...
   def GenerateTaskList(self, configSpec: ConfigSpec, host: HostSystem) -> Task: ...
   def QueryProfileMetadata(self, profileName: list[type], profile: Optional[Profile]) -> list[ProfileMetadata]: ...
   def QueryProfileStructure(self, profile: Optional[Profile]) -> ProfileStructure: ...
   def CreateDefaultProfile(self, profileType: type, profileTypeName: Optional[str], profile: Optional[Profile]) -> ApplyProfile: ...
   def UpdateAnswerFile(self, host: HostSystem, configSpec: AnswerFileCreateSpec) -> Task: ...
   def RetrieveAnswerFile(self, host: HostSystem) -> Optional[AnswerFile]: ...
   def RetrieveAnswerFileForProfile(self, host: HostSystem, applyProfile: HostApplyProfile) -> Optional[AnswerFile]: ...
   def ExportAnswerFile(self, host: HostSystem) -> Task: ...
   def CheckAnswerFileStatus(self, host: list[HostSystem]) -> Task: ...
   def QueryAnswerFileStatus(self, host: list[HostSystem]) -> list[AnswerFileStatusResult]: ...
   def RetrieveHostCustomizations(self, hosts: list[HostSystem]) -> list[StructuredCustomizations]: ...
   def RetrieveHostCustomizationsForProfile(self, hosts: list[HostSystem], applyProfile: HostApplyProfile) -> list[StructuredCustomizations]: ...
   def GenerateHostConfigTaskSpec(self, hostsInfo: list[StructuredCustomizations]) -> Task: ...
   def ApplyEntitiesConfiguration(self, applyConfigSpecs: list[ApplyHostConfigSpec]) -> Task: ...
   def ValidateComposition(self, source: Profile, targets: list[Profile], toBeMerged: Optional[HostApplyProfile], toReplaceWith: Optional[HostApplyProfile], toBeDeleted: Optional[HostApplyProfile], enableStatusToBeCopied: Optional[HostApplyProfile], errorOnly: Optional[bool]) -> Task: ...
   def CompositeProfile(self, source: Profile, targets: list[Profile], toBeMerged: Optional[HostApplyProfile], toBeReplacedWith: Optional[HostApplyProfile], toBeDeleted: Optional[HostApplyProfile], enableStatusToBeCopied: Optional[HostApplyProfile]) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.event import ComputeResourceEventArgument
from pyVmomi.vim.event import DatacenterEventArgument
from pyVmomi.vim.event import DatastoreEventArgument
from pyVmomi.vim.event import DvsEventArgument
from pyVmomi.vim.event import HostEventArgument
from pyVmomi.vim.event import NetworkEventArgument
from pyVmomi.vim.event import VmEventArgument

class Event(DynamicData):
   class EventSeverity(Enum):
      error: ClassVar['EventSeverity'] = 'error'
      warning: ClassVar['EventSeverity'] = 'warning'
      info: ClassVar['EventSeverity'] = 'info'
      user: ClassVar['EventSeverity'] = 'user'

   key: int
   chainId: int
   createdTime: datetime
   userName: str
   datacenter: Optional[DatacenterEventArgument] = None
   computeResource: Optional[ComputeResourceEventArgument] = None
   host: Optional[HostEventArgument] = None
   vm: Optional[VmEventArgument] = None
   ds: Optional[DatastoreEventArgument] = None
   net: Optional[NetworkEventArgument] = None
   dvs: Optional[DvsEventArgument] = None
   fullFormattedMessage: Optional[str] = None
   changeTag: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import VsanUpgradeSystem

class VsanDiskFormatConversionCheckResult(VsanUpgradeSystem.PreflightCheckResult):
   isSupported: bool
   targetVersion: Optional[int] = None
   isDataMovementRequired: Optional[bool] = None
   storagePoolDisk: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

class PatchManager(ManagedObject):
   class Result(DynamicData):
      version: str
      status: list[Status] = []
      xmlResult: Optional[str] = None

   class Status(DynamicData):
      class Reason(Enum):
         obsoleted: ClassVar['Reason'] = 'obsoleted'
         missingPatch: ClassVar['Reason'] = 'missingPatch'
         missingLib: ClassVar['Reason'] = 'missingLib'
         hasDependentPatch: ClassVar['Reason'] = 'hasDependentPatch'
         conflictPatch: ClassVar['Reason'] = 'conflictPatch'
         conflictLib: ClassVar['Reason'] = 'conflictLib'

      class Integrity(Enum):
         validated: ClassVar['Integrity'] = 'validated'
         keyNotFound: ClassVar['Integrity'] = 'keyNotFound'
         keyRevoked: ClassVar['Integrity'] = 'keyRevoked'
         keyExpired: ClassVar['Integrity'] = 'keyExpired'
         digestMismatch: ClassVar['Integrity'] = 'digestMismatch'
         notEnoughSignatures: ClassVar['Integrity'] = 'notEnoughSignatures'
         validationError: ClassVar['Integrity'] = 'validationError'

      class InstallState(Enum):
         hostRestarted: ClassVar['InstallState'] = 'hostRestarted'
         imageActive: ClassVar['InstallState'] = 'imageActive'

      class PrerequisitePatch(DynamicData):
         id: str
         installState: list[str] = []

      id: str
      applicable: bool
      reason: list[str] = []
      integrity: Optional[str] = None
      installed: bool
      installState: list[str] = []
      prerequisitePatch: list[PrerequisitePatch] = []
      restartRequired: bool
      reconnectRequired: bool
      vmOffRequired: bool
      supersededPatchIds: list[str] = []

   class Locator(DynamicData):
      url: str
      proxy: Optional[str] = None

   class PatchManagerOperationSpec(DynamicData):
      proxy: Optional[str] = None
      port: Optional[int] = None
      userName: Optional[str] = None
      password: Optional[str] = None
      cmdOption: Optional[str] = None

   def Check(self, metaUrls: list[str], bundleUrls: list[str], spec: Optional[PatchManagerOperationSpec]) -> Task: ...
   def Scan(self, repository: Locator, updateID: list[str]) -> Task: ...
   def ScanV2(self, metaUrls: list[str], bundleUrls: list[str], spec: Optional[PatchManagerOperationSpec]) -> Task: ...
   def Stage(self, metaUrls: list[str], bundleUrls: list[str], vibUrls: list[str], spec: Optional[PatchManagerOperationSpec]) -> Task: ...
   def Install(self, repository: Locator, updateID: str, force: Optional[bool]) -> Task: ...
   def InstallV2(self, metaUrls: list[str], bundleUrls: list[str], vibUrls: list[str], spec: Optional[PatchManagerOperationSpec]) -> Task: ...
   def Uninstall(self, bulletinIds: list[str], spec: Optional[PatchManagerOperationSpec]) -> Task: ...
   def Query(self, spec: Optional[PatchManagerOperationSpec]) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanVdsPgMigrationVmInfo

class VsanVdsPgMigrationHostInfo(DynamicData):
   host: HostSystem
   hostname: str
   vmknicDevices: list[str] = []
   vmVnics: list[VsanVdsPgMigrationVmInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class SolutionManagerInfo(DynamicData):
   class TabInfo(DynamicData):
      label: str
      url: str

   tab: list[TabInfo] = []
   smallIconUrl: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.pbm import ServerObjectRef

from pyVmomi.pbm.replication import QueryReplicationGroupResult

class ReplicationManager(ManagedObject):
   def QueryReplicationGroups(self, entities: list[ServerObjectRef]) -> list[QueryReplicationGroupResult]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

class GraphicsInfo(DynamicData):
   class GraphicsType(Enum):
      basic: ClassVar['GraphicsType'] = 'basic'
      shared: ClassVar['GraphicsType'] = 'shared'
      direct: ClassVar['GraphicsType'] = 'direct'
      sharedDirect: ClassVar['GraphicsType'] = 'sharedDirect'

   class VgpuMode(Enum):
      none: ClassVar['VgpuMode'] = 'none'
      sameSize: ClassVar['VgpuMode'] = 'sameSize'
      mixedSize: ClassVar['VgpuMode'] = 'mixedSize'
      multiInstanceGpu: ClassVar['VgpuMode'] = 'multiInstanceGpu'

   deviceName: str
   vendorName: str
   pciId: str
   graphicsType: str
   vgpuMode: Optional[str] = None
   memorySizeInKB: long
   vm: list[VirtualMachine] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import Datastore
from pyVmomi.vim import HostSystem
from pyVmomi.vim import StoragePod
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import RuleInfo

from pyVmomi.vim.vm import CloneSpec
from pyVmomi.vim.vm import ConfigSpec
from pyVmomi.vim.vm import RelocateSpec

class PlacementSpec(DynamicData):
   class PlacementType(Enum):
      create: ClassVar['PlacementType'] = 'create'
      reconfigure: ClassVar['PlacementType'] = 'reconfigure'
      relocate: ClassVar['PlacementType'] = 'relocate'
      clone: ClassVar['PlacementType'] = 'clone'

   priority: Optional[VirtualMachine.MovePriority] = None
   vm: Optional[VirtualMachine] = None
   configSpec: Optional[ConfigSpec] = None
   relocateSpec: Optional[RelocateSpec] = None
   hosts: list[HostSystem] = []
   datastores: list[Datastore] = []
   storagePods: list[StoragePod] = []
   disallowPrerequisiteMoves: Optional[bool] = None
   rules: list[RuleInfo] = []
   key: Optional[str] = None
   placementType: Optional[str] = None
   cloneSpec: Optional[CloneSpec] = None
   cloneName: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import HostSystem
from pyVmomi.vim import ResourcePool
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.vm import ConfigSpec

class CompatibilityChecker(ManagedObject):
   def CheckCompatibility(self, vm: VirtualMachine, host: Optional[HostSystem], pool: Optional[ResourcePool], testType: list[str]) -> Task: ...
   def CheckVmConfig(self, spec: ConfigSpec, vm: Optional[VirtualMachine], host: Optional[HostSystem], pool: Optional[ResourcePool], testType: list[str]) -> Task: ...
   def CheckPowerOn(self, vm: VirtualMachine, host: Optional[HostSystem], pool: Optional[ResourcePool], testType: list[str]) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedMethod

from pyVmomi.vim import AuthorizationManager
from pyVmomi.vim import CustomFieldsManager
from pyVmomi.vim import ExtensibleManagedObject
from pyVmomi.vim import Tag
from pyVmomi.vim import Task

from pyVmomi.vim.alarm import AlarmState

from pyVmomi.vim.event import Event

class ManagedEntity(ExtensibleManagedObject):
   class Status(Enum):
      gray: ClassVar['Status'] = 'gray'
      green: ClassVar['Status'] = 'green'
      yellow: ClassVar['Status'] = 'yellow'
      red: ClassVar['Status'] = 'red'

   @property
   def parent(self) -> Optional[ManagedEntity]: ...
   @property
   def customValue(self) -> list[CustomFieldsManager.Value]: ...
   @property
   def overallStatus(self) -> Status: ...
   @property
   def configStatus(self) -> Status: ...
   @property
   def configIssue(self) -> list[Event]: ...
   @property
   def effectiveRole(self) -> list[int]: ...
   @property
   def permission(self) -> list[AuthorizationManager.Permission]: ...
   @property
   def name(self) -> str: ...
   @property
   def disabledMethod(self) -> list[ManagedMethod]: ...
   @property
   def recentTask(self) -> list[Task]: ...
   @property
   def declaredAlarmState(self) -> list[AlarmState]: ...
   @property
   def triggeredAlarmState(self) -> list[AlarmState]: ...
   @property
   def alarmActionsEnabled(self) -> Optional[bool]: ...
   @property
   def tag(self) -> list[Tag]: ...

   def Reload(self) -> NoReturn: ...
   def Rename(self, newName: str) -> Task: ...
   def Destroy(self) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore
from pyVmomi.vim import Task

from pyVmomi.vim.vslm import ID
from pyVmomi.vim.vslm import VClockInfo

class VStorageObjectManagerBase(ManagedObject):
   def ExtendDiskEx(self, id: ID, datastore: Datastore, newCapacityInMB: long) -> Task: ...
   def RenameVStorageObjectEx(self, id: ID, datastore: Datastore, name: str) -> VClockInfo: ...
   def CreateSnapshotEx(self, id: ID, datastore: Datastore, description: str) -> Task: ...
   def DeleteSnapshotEx(self, id: ID, datastore: Datastore, snapshotId: ID) -> Task: ...
   def DeleteSnapshotEx2(self, id: ID, datastore: Datastore, snapshotId: ID) -> Task: ...
   def RevertVStorageObjectEx(self, id: ID, datastore: Datastore, snapshotId: ID) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

class EntityConfigInfo(DynamicData):
   class Action(Enum):
      none: ClassVar['Action'] = 'none'
      powerOn: ClassVar['Action'] = 'powerOn'
      powerOff: ClassVar['Action'] = 'powerOff'
      guestShutdown: ClassVar['Action'] = 'guestShutdown'
      suspend: ClassVar['Action'] = 'suspend'

   key: Optional[ManagedEntity] = None
   tag: Optional[str] = None
   startOrder: Optional[int] = None
   startDelay: Optional[int] = None
   waitingForGuest: Optional[bool] = None
   startAction: Optional[str] = None
   stopDelay: Optional[int] = None
   stopAction: Optional[str] = None
   destroyWithParent: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan.host import DecommissionMode

class MaintenanceSpec(DynamicData):
   class Purpose(Enum):
      hostUpgrade: ClassVar['Purpose'] = 'hostUpgrade'

   vsanMode: Optional[DecommissionMode] = None
   purpose: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.vim import ExtensibleManagedObject

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import IpConfig
from pyVmomi.vim.host import VirtualNic

class VMotionSystem(ExtensibleManagedObject):
   class NetConfig(DynamicData):
      candidateVnic: list[VirtualNic] = []
      selectedVnic: Optional[VirtualNic] = None

   @property
   def netConfig(self) -> Optional[NetConfig]: ...
   @property
   def ipConfig(self) -> Optional[IpConfig]: ...

   def UpdateIpConfig(self, ipConfig: IpConfig) -> NoReturn: ...
   def SelectVnic(self, device: str) -> NoReturn: ...
   def DeselectVnic(self) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import VirtualHardwareCompatibilityIssue

class DeviceNotSupported(VirtualHardwareCompatibilityIssue):
   class Reason(Enum):
      host: ClassVar['Reason'] = 'host'
      guest: ClassVar['Reason'] = 'guest'
      ft: ClassVar['Reason'] = 'ft'

   device: str
   reason: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.pbm import ServerObjectRef

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.pbm.compliance import ComplianceResult

class RollupComplianceResult(DynamicData):
   oldestCheckTime: datetime
   entity: ServerObjectRef
   overallComplianceStatus: str
   overallComplianceTaskStatus: Optional[str] = None
   result: list[ComplianceResult] = []
   errorCause: list[MethodFault] = []
   profileMismatch: bool



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import capability as capability
from . import dr as dr

from .InvalidProtectionReason import InvalidProtectionReason as InvalidProtectionReason
from .MigrationType import MigrationType as MigrationType
from .ProtectionStatusType import ProtectionStatusType as ProtectionStatusType
from .ProtectionSupportType import ProtectionSupportType as ProtectionSupportType
from .SnapshotType import SnapshotType as SnapshotType
from .SyncType import SyncType as SyncType
from .VSphereDataProtectionCapabilities import VSphereDataProtectionCapabilities as VSphereDataProtectionCapabilities
from .VssBackupContext import VssBackupContext as VssBackupContext
from .VssBackupType import VssBackupType as VssBackupType



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ElementDescription

from pyVmomi.vim.host import FeatureCapability
from pyVmomi.vim.host import FeatureMask

from pyVmomi.vim.vm import FeatureRequirement

class FeatureEVCMode(ElementDescription):
   mask: list[FeatureMask] = []
   capability: list[FeatureCapability] = []
   requirement: list[FeatureRequirement] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vim import ClusterComputeResource

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanClusterAdvCfgSyncResult
from pyVmomi.vim.cluster import VsanClusterBalanceSummary
from pyVmomi.vim.cluster import VsanClusterClomdLivenessResult
from pyVmomi.vim.cluster import VsanClusterDitEncryptionHealthSummary
from pyVmomi.vim.cluster import VsanClusterEncryptionHealthSummary
from pyVmomi.vim.cluster import VsanClusterFileServiceHealthSummary
from pyVmomi.vim.cluster import VsanClusterGlobalDedupHealthSummary
from pyVmomi.vim.cluster import VsanClusterHclInfo
from pyVmomi.vim.cluster import VsanClusterHealthGroup
from pyVmomi.vim.cluster import VsanClusterHealthSystemStatusResult
from pyVmomi.vim.cluster import VsanClusterHealthSystemVersionResult
from pyVmomi.vim.cluster import VsanClusterLimitHealthResult
from pyVmomi.vim.cluster import VsanClusterNetworkHealthResult
from pyVmomi.vim.cluster import VsanClusterVMsHealthOverallResult
from pyVmomi.vim.cluster import VsanHostCreateVmHealthTestResult

from pyVmomi.vim.host import VsanObjectOverallHealth
from pyVmomi.vim.host import VsanPhysicalDiskHealthSummary

from pyVmomi.vim.vsan import VsanBurnInTestCheckResult
from pyVmomi.vim.vsan import VsanConfigCheckResult
from pyVmomi.vim.vsan import VsanGenericClusterBestPracticeHealth
from pyVmomi.vim.vsan import VsanNetworkConfigBestPracticeHealth
from pyVmomi.vim.vsan import VsanPerfsvcHealthResult

class VsanClusterHealthSummary(DynamicData):
   clusterStatus: Optional[VsanClusterHealthSystemStatusResult] = None
   timestamp: Optional[datetime] = None
   clusterVersions: Optional[VsanClusterHealthSystemVersionResult] = None
   objectHealth: Optional[VsanObjectOverallHealth] = None
   vmHealth: Optional[VsanClusterVMsHealthOverallResult] = None
   networkHealth: Optional[VsanClusterNetworkHealthResult] = None
   limitHealth: Optional[VsanClusterLimitHealthResult] = None
   advCfgSync: list[VsanClusterAdvCfgSyncResult] = []
   createVmHealth: list[VsanHostCreateVmHealthTestResult] = []
   physicalDisksHealth: list[VsanPhysicalDiskHealthSummary] = []
   encryptionHealth: Optional[VsanClusterEncryptionHealthSummary] = None
   hclInfo: Optional[VsanClusterHclInfo] = None
   groups: list[VsanClusterHealthGroup] = []
   overallHealth: str
   overallHealthDescription: str
   clomdLiveness: Optional[VsanClusterClomdLivenessResult] = None
   diskBalance: Optional[VsanClusterBalanceSummary] = None
   genericCluster: Optional[VsanGenericClusterBestPracticeHealth] = None
   networkConfig: Optional[VsanNetworkConfigBestPracticeHealth] = None
   vsanConfig: Optional[VsanConfigCheckResult] = None
   burnInTest: Optional[VsanBurnInTestCheckResult] = None
   perfsvcHealth: Optional[VsanPerfsvcHealthResult] = None
   cluster: Optional[ClusterComputeResource] = None
   fileServiceHealth: Optional[VsanClusterFileServiceHealthSummary] = None
   ditEncryptionHealth: Optional[VsanClusterDitEncryptionHealthSummary] = None
   healthScore: Optional[int] = None
   globalDedupHealth: Optional[VsanClusterGlobalDedupHealthSummary] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualVMCIDevice(VirtualDevice):
   class Action(Enum):
      allow: ClassVar['Action'] = 'allow'
      deny: ClassVar['Action'] = 'deny'

   class Protocol(Enum):
      hypervisor: ClassVar['Protocol'] = 'hypervisor'
      doorbell: ClassVar['Protocol'] = 'doorbell'
      queuepair: ClassVar['Protocol'] = 'queuepair'
      datagram: ClassVar['Protocol'] = 'datagram'
      stream: ClassVar['Protocol'] = 'stream'
      anyProtocol: ClassVar['Protocol'] = 'anyProtocol'

   class Direction(Enum):
      guest: ClassVar['Direction'] = 'guest'
      host: ClassVar['Direction'] = 'host'
      anyDirection: ClassVar['Direction'] = 'anyDirection'

   class FilterSpec(DynamicData):
      rank: long
      action: str
      protocol: str
      direction: str
      lowerDstPortBoundary: Optional[long] = None
      upperDstPortBoundary: Optional[long] = None

   class FilterInfo(DynamicData):
      filters: list[FilterSpec] = []

   id: Optional[long] = None
   allowUnrestrictedCommunication: Optional[bool] = None
   filterEnable: Optional[bool] = None
   filterInfo: Optional[FilterInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import CapacityReservationInfo
from pyVmomi.vim.vsan import ProactiveRebalanceInfo

class VsanExtendedConfig(DynamicData):
   objectRepairTimer: Optional[long] = None
   disableSiteReadLocality: Optional[bool] = None
   enableCustomizedSwapObject: Optional[bool] = None
   largeScaleClusterSupport: Optional[bool] = None
   proactiveRebalanceInfo: Optional[ProactiveRebalanceInfo] = None
   capacityReservationInfo: Optional[CapacityReservationInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.host import NasVolume
from pyVmomi.vim.host import ScsiDisk
from pyVmomi.vim.host import UnresolvedVmfsResignatureSpec
from pyVmomi.vim.host import UnresolvedVmfsVolume
from pyVmomi.vim.host import VmfsDatastoreCreateSpec
from pyVmomi.vim.host import VmfsDatastoreExpandSpec
from pyVmomi.vim.host import VmfsDatastoreExtendSpec
from pyVmomi.vim.host import VmfsDatastoreOption

class DatastoreSystem(ManagedObject):
   class Capabilities(DynamicData):
      nfsMountCreationRequired: bool
      nfsMountCreationSupported: bool
      localDatastoreSupported: bool
      vmfsExtentExpansionSupported: bool

   class VvolDatastoreSpec(DynamicData):
      name: str
      scId: str

   class DatastoreResult(DynamicData):
      key: Datastore
      fault: Optional[MethodFault] = None

   @property
   def datastore(self) -> list[Datastore]: ...
   @property
   def capabilities(self) -> Capabilities: ...

   def UpdateLocalSwapDatastore(self, datastore: Optional[Datastore]) -> NoReturn: ...
   def QueryAvailableDisksForVmfs(self, datastore: Optional[Datastore]) -> list[ScsiDisk]: ...
   def QueryVmfsDatastoreCreateOptions(self, devicePath: str, vmfsMajorVersion: Optional[int]) -> list[VmfsDatastoreOption]: ...
   def CreateVmfsDatastore(self, spec: VmfsDatastoreCreateSpec) -> Datastore: ...
   def QueryVmfsDatastoreExtendOptions(self, datastore: Datastore, devicePath: str, suppressExpandCandidates: Optional[bool]) -> list[VmfsDatastoreOption]: ...
   def QueryVmfsDatastoreExpandOptions(self, datastore: Datastore) -> list[VmfsDatastoreOption]: ...
   def ExtendVmfsDatastore(self, datastore: Datastore, spec: VmfsDatastoreExtendSpec) -> Datastore: ...
   def EnableClusteredVmdkSupport(self, datastore: Datastore) -> NoReturn: ...
   def DisableClusteredVmdkSupport(self, datastore: Datastore) -> NoReturn: ...
   def ExpandVmfsDatastore(self, datastore: Datastore, spec: VmfsDatastoreExpandSpec) -> Datastore: ...
   def CreateNasDatastore(self, spec: NasVolume.Specification) -> Datastore: ...
   def CreateLocalDatastore(self, name: str, path: str) -> Datastore: ...
   def CreateVvolDatastore(self, spec: VvolDatastoreSpec) -> Datastore: ...
   def RemoveDatastore(self, datastore: Datastore) -> NoReturn: ...
   def SetMaxQueueDepth(self, datastore: Datastore, maxQdepth: long) -> NoReturn: ...
   def QueryMaxQueueDepth(self, datastore: Datastore) -> long: ...
   def RemoveDatastoreEx(self, datastore: list[Datastore]) -> Task: ...
   def ConfigureDatastorePrincipal(self, userName: str, password: Optional[str]) -> NoReturn: ...
   def QueryUnresolvedVmfsVolumes(self) -> list[UnresolvedVmfsVolume]: ...
   def ResignatureUnresolvedVmfsVolume(self, resolutionSpec: UnresolvedVmfsResignatureSpec) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ComputeResource
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.dvs import VmwareDistributedVirtualSwitch

from pyVmomi.vim.vsan import VsanVdsMigrationPlan

class VsanVdsSystem(ManagedObject):
   def VsanVdsGetMigrationPlan(self, cluster: ComputeResource, vswitchName: Optional[str], vdsName: Optional[str], vmnicDevices: list[str], infraVm: list[VirtualMachine], vds: Optional[VmwareDistributedVirtualSwitch], hosts: list[HostSystem]) -> VsanVdsMigrationPlan: ...
   def VsanVdsMigrateVss(self, cluster: ComputeResource, migrationPlan: Optional[VsanVdsMigrationPlan], vswitchName: Optional[str], vdsName: Optional[str], vmnicDevices: list[str], infraVm: list[VirtualMachine], vds: Optional[VmwareDistributedVirtualSwitch], hosts: list[HostSystem]) -> Task: ...
   def VsanVssMigrateVds(self, cluster: Optional[ComputeResource], hosts: list[HostSystem], vds: VmwareDistributedVirtualSwitch, vswitchName: Optional[str], vmnicDevices: list[str], infraVm: list[VirtualMachine]) -> Task: ...
   def RollbackVdsToVss(self, task: Task) -> bool: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .CapabilityConstraintsRequirement import CapabilityConstraintsRequirement as CapabilityConstraintsRequirement
from .CapabilityProfileRequirement import CapabilityProfileRequirement as CapabilityProfileRequirement
from .CompatibilityResult import CompatibilityResult as CompatibilityResult
from .MatchingReplicationResources import MatchingReplicationResources as MatchingReplicationResources
from .MatchingResources import MatchingResources as MatchingResources
from .PlacementHub import PlacementHub as PlacementHub
from .PlacementSolver import PlacementSolver as PlacementSolver
from .Requirement import Requirement as Requirement
from .ResourceUtilization import ResourceUtilization as ResourceUtilization



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VsanHclFirmwareUpdateSpec

from pyVmomi.vim.vsan import VsanDownloadItem
from pyVmomi.vim.vsan import VsanVibSpec

class VsanUpdateItem(DynamicData):
   host: HostSystem
   type: str
   name: str
   version: str
   existingVersion: Optional[str] = None
   present: bool
   vibSpec: list[VsanVibSpec] = []
   vibType: Optional[str] = None
   firmwareSpec: Optional[VsanHclFirmwareUpdateSpec] = None
   downloadInfo: list[VsanDownloadItem] = []
   eula: Optional[str] = None
   adapter: Optional[str] = None
   key: Optional[str] = None
   impact: Optional[str] = None
   firmwareUnknown: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.profile import ApplyProfile

from pyVmomi.vim.profile.host import DvsHostVNicProfile
from pyVmomi.vim.profile.host import DvsProfile
from pyVmomi.vim.profile.host import DvsServiceConsoleVNicProfile
from pyVmomi.vim.profile.host import HostPortGroupProfile
from pyVmomi.vim.profile.host import IpRouteProfile
from pyVmomi.vim.profile.host import NetStackInstanceProfile
from pyVmomi.vim.profile.host import NsxHostVNicProfile
from pyVmomi.vim.profile.host import OpaqueSwitchProfile
from pyVmomi.vim.profile.host import PhysicalNicProfile
from pyVmomi.vim.profile.host import ServiceConsolePortGroupProfile
from pyVmomi.vim.profile.host import VirtualSwitchProfile
from pyVmomi.vim.profile.host import VmPortGroupProfile

class NetworkProfile(ApplyProfile):
   class DnsConfigProfile(ApplyProfile):
      pass

   vswitch: list[VirtualSwitchProfile] = []
   vmPortGroup: list[VmPortGroupProfile] = []
   hostPortGroup: list[HostPortGroupProfile] = []
   serviceConsolePortGroup: list[ServiceConsolePortGroupProfile] = []
   dnsConfig: Optional[DnsConfigProfile] = None
   ipRouteConfig: Optional[IpRouteProfile] = None
   consoleIpRouteConfig: Optional[IpRouteProfile] = None
   pnic: list[PhysicalNicProfile] = []
   dvswitch: list[DvsProfile] = []
   dvsServiceConsoleNic: list[DvsServiceConsoleVNicProfile] = []
   dvsHostNic: list[DvsHostVNicProfile] = []
   nsxHostNic: list[NsxHostVNicProfile] = []
   netStackInstance: list[NetStackInstanceProfile] = []
   opaqueSwitch: Optional[OpaqueSwitchProfile] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim.host import HostBusAdapter

class FibreChannelHba(HostBusAdapter):
   class PortType(Enum):
      fabric: ClassVar['PortType'] = 'fabric'
      loop: ClassVar['PortType'] = 'loop'
      pointToPoint: ClassVar['PortType'] = 'pointToPoint'
      unknown: ClassVar['PortType'] = 'unknown'

   portWorldWideName: long
   nodeWorldWideName: long
   portType: PortType
   speed: long



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.host import VsanHclCommonDeviceInfo
from pyVmomi.vim.host import VsanNicRdmaInfo

class VsanHclNicInfo(VsanHclCommonDeviceInfo):
   vmknic: Optional[str] = None
   useByVsan: Optional[bool] = None
   rdmaConfig: Optional[VsanNicRdmaInfo] = None
   vsanHostCompatibility: list[str] = []
   nicLinkSpeedInMbps: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class BIOSInfo(DynamicData):
   class FirmwareType(Enum):
      BIOS: ClassVar['FirmwareType'] = 'BIOS'
      UEFI: ClassVar['FirmwareType'] = 'UEFI'

   biosVersion: Optional[str] = None
   releaseDate: Optional[datetime] = None
   vendor: Optional[str] = None
   majorRelease: Optional[int] = None
   minorRelease: Optional[int] = None
   firmwareMajorRelease: Optional[int] = None
   firmwareMinorRelease: Optional[int] = None
   firmwareType: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan.host import DiskMapInfoEx
from pyVmomi.vim.vsan.host import StoragePoolInfo
from pyVmomi.vim.vsan.host import VsanDirectStorage
from pyVmomi.vim.vsan.host import VsanManagedPMemInfo

class VsanManagedDisksInfo(DynamicData):
   vSANDirectDisks: list[VsanDirectStorage] = []
   vSANDiskMapInfo: list[DiskMapInfoEx] = []
   vSANPMemInfo: Optional[VsanManagedPMemInfo] = None
   storagePools: list[StoragePoolInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class BackingStoragePool(DynamicData):
   class BackingStoragePoolType(Enum):
      thinProvisioningPool: ClassVar['BackingStoragePoolType'] = 'thinProvisioningPool'
      deduplicationPool: ClassVar['BackingStoragePoolType'] = 'deduplicationPool'
      thinAndDeduplicationCombinedPool: ClassVar['BackingStoragePoolType'] = 'thinAndDeduplicationCombinedPool'

   uuid: str
   type: str
   capacityInMB: long
   usedSpaceInMB: long



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.net import DhcpConfigInfo
from pyVmomi.vim.net import DnsConfigInfo
from pyVmomi.vim.net import IpConfigInfo
from pyVmomi.vim.net import IpRouteConfigInfo
from pyVmomi.vim.net import NetBIOSConfigInfo

class GuestInfo(DynamicData):
   class ToolsStatus(Enum):
      toolsNotInstalled: ClassVar['ToolsStatus'] = 'toolsNotInstalled'
      toolsNotRunning: ClassVar['ToolsStatus'] = 'toolsNotRunning'
      toolsOld: ClassVar['ToolsStatus'] = 'toolsOld'
      toolsOk: ClassVar['ToolsStatus'] = 'toolsOk'

   class ToolsVersionStatus(Enum):
      guestToolsNotInstalled: ClassVar['ToolsVersionStatus'] = 'guestToolsNotInstalled'
      guestToolsNeedUpgrade: ClassVar['ToolsVersionStatus'] = 'guestToolsNeedUpgrade'
      guestToolsCurrent: ClassVar['ToolsVersionStatus'] = 'guestToolsCurrent'
      guestToolsUnmanaged: ClassVar['ToolsVersionStatus'] = 'guestToolsUnmanaged'
      guestToolsTooOld: ClassVar['ToolsVersionStatus'] = 'guestToolsTooOld'
      guestToolsSupportedOld: ClassVar['ToolsVersionStatus'] = 'guestToolsSupportedOld'
      guestToolsSupportedNew: ClassVar['ToolsVersionStatus'] = 'guestToolsSupportedNew'
      guestToolsTooNew: ClassVar['ToolsVersionStatus'] = 'guestToolsTooNew'
      guestToolsBlacklisted: ClassVar['ToolsVersionStatus'] = 'guestToolsBlacklisted'

   class ToolsRunningStatus(Enum):
      guestToolsNotRunning: ClassVar['ToolsRunningStatus'] = 'guestToolsNotRunning'
      guestToolsRunning: ClassVar['ToolsRunningStatus'] = 'guestToolsRunning'
      guestToolsExecutingScripts: ClassVar['ToolsRunningStatus'] = 'guestToolsExecutingScripts'

   class ToolsInstallType(Enum):
      guestToolsTypeUnknown: ClassVar['ToolsInstallType'] = 'guestToolsTypeUnknown'
      guestToolsTypeMSI: ClassVar['ToolsInstallType'] = 'guestToolsTypeMSI'
      guestToolsTypeTar: ClassVar['ToolsInstallType'] = 'guestToolsTypeTar'
      guestToolsTypeOSP: ClassVar['ToolsInstallType'] = 'guestToolsTypeOSP'
      guestToolsTypeOpenVMTools: ClassVar['ToolsInstallType'] = 'guestToolsTypeOpenVMTools'

   class VirtualDiskMapping(DynamicData):
      key: int

   class DiskInfo(DynamicData):
      diskPath: Optional[str] = None
      capacity: Optional[long] = None
      freeSpace: Optional[long] = None
      filesystemType: Optional[str] = None
      mappings: list[VirtualDiskMapping] = []

   class NicInfo(DynamicData):
      network: Optional[str] = None
      ipAddress: list[str] = []
      macAddress: Optional[str] = None
      connected: bool
      deviceConfigId: int
      dnsConfig: Optional[DnsConfigInfo] = None
      ipConfig: Optional[IpConfigInfo] = None
      netBIOSConfig: Optional[NetBIOSConfigInfo] = None

   class StackInfo(DynamicData):
      dnsConfig: Optional[DnsConfigInfo] = None
      ipRouteConfig: Optional[IpRouteConfigInfo] = None
      ipStackConfig: list[KeyValue] = []
      dhcpConfig: Optional[DhcpConfigInfo] = None

   class ScreenInfo(DynamicData):
      width: int
      height: int

   class GuestState(Enum):
      running: ClassVar['GuestState'] = 'running'
      shuttingDown: ClassVar['GuestState'] = 'shuttingDown'
      resetting: ClassVar['GuestState'] = 'resetting'
      standby: ClassVar['GuestState'] = 'standby'
      notRunning: ClassVar['GuestState'] = 'notRunning'
      unknown: ClassVar['GuestState'] = 'unknown'

   class AppStateType(Enum):
      none: ClassVar['AppStateType'] = 'none'
      appStateOk: ClassVar['AppStateType'] = 'appStateOk'
      appStateNeedReset: ClassVar['AppStateType'] = 'appStateNeedReset'

   class NamespaceGenerationInfo(DynamicData):
      key: str
      generationNo: int

   class CustomizationStatus(Enum):
      TOOLSDEPLOYPKG_IDLE: ClassVar['CustomizationStatus'] = 'TOOLSDEPLOYPKG_IDLE'
      TOOLSDEPLOYPKG_PENDING: ClassVar['CustomizationStatus'] = 'TOOLSDEPLOYPKG_PENDING'
      TOOLSDEPLOYPKG_RUNNING: ClassVar['CustomizationStatus'] = 'TOOLSDEPLOYPKG_RUNNING'
      TOOLSDEPLOYPKG_SUCCEEDED: ClassVar['CustomizationStatus'] = 'TOOLSDEPLOYPKG_SUCCEEDED'
      TOOLSDEPLOYPKG_FAILED: ClassVar['CustomizationStatus'] = 'TOOLSDEPLOYPKG_FAILED'

   class CustomizationInfo(DynamicData):
      customizationStatus: str
      startTime: Optional[datetime] = None
      endTime: Optional[datetime] = None
      errorMsg: Optional[str] = None

   toolsStatus: Optional[ToolsStatus] = None
   toolsVersionStatus: Optional[str] = None
   toolsVersionStatus2: Optional[str] = None
   toolsRunningStatus: Optional[str] = None
   toolsVersion: Optional[str] = None
   toolsInstallType: Optional[str] = None
   guestId: Optional[str] = None
   guestFamily: Optional[str] = None
   guestFullName: Optional[str] = None
   guestDetailedData: Optional[str] = None
   hostName: Optional[str] = None
   ipAddress: Optional[str] = None
   net: list[NicInfo] = []
   ipStack: list[StackInfo] = []
   disk: list[DiskInfo] = []
   screen: Optional[ScreenInfo] = None
   guestState: str
   appHeartbeatStatus: Optional[str] = None
   guestKernelCrashed: Optional[bool] = None
   appState: Optional[str] = None
   guestOperationsReady: Optional[bool] = None
   interactiveGuestOperationsReady: Optional[bool] = None
   guestStateChangeSupported: Optional[bool] = None
   generationInfo: list[NamespaceGenerationInfo] = []
   hwVersion: Optional[str] = None
   customizationInfo: Optional[CustomizationInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import ConfigSpec
from pyVmomi.vim.vm import RelocateSpec
from pyVmomi.vim.vm import Snapshot

from pyVmomi.vim.vm.customization import Specification

class CloneSpec(DynamicData):
   class TpmProvisionPolicy(Enum):
      copy: ClassVar['TpmProvisionPolicy'] = 'copy'
      replace: ClassVar['TpmProvisionPolicy'] = 'replace'

   location: RelocateSpec
   template: bool
   config: Optional[ConfigSpec] = None
   customization: Optional[Specification] = None
   powerOn: bool
   snapshot: Optional[Snapshot] = None
   memory: Optional[bool] = None
   tpmProvisionPolicy: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import AuthorizationDescription
from pyVmomi.vim import Description
from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

class AuthorizationManager(ManagedObject):
   class Permission(DynamicData):
      entity: Optional[ManagedEntity] = None
      principal: str
      group: bool
      roleId: int
      propagate: bool

   class Role(DynamicData):
      roleId: int
      system: bool
      name: str
      info: Description
      privilege: list[str] = []

   class Privilege(DynamicData):
      privId: str
      onParent: bool
      name: str
      privGroupName: str

   class PrivilegeAvailability(DynamicData):
      privId: str
      isGranted: bool

   class EntityPrivilege(DynamicData):
      entity: ManagedEntity
      privAvailability: list[PrivilegeAvailability] = []

   class UserPrivilegeResult(DynamicData):
      entity: ManagedEntity
      privileges: list[str] = []

   @property
   def privilegeList(self) -> list[Privilege]: ...
   @property
   def roleList(self) -> list[Role]: ...
   @property
   def description(self) -> AuthorizationDescription: ...

   def AddRole(self, name: str, privIds: list[str]) -> int: ...
   def RemoveRole(self, roleId: int, failIfUsed: bool) -> NoReturn: ...
   def UpdateRole(self, roleId: int, newName: str, privIds: list[str]) -> NoReturn: ...
   def MergePermissions(self, srcRoleId: int, dstRoleId: int) -> NoReturn: ...
   def RetrieveRolePermissions(self, roleId: int) -> list[Permission]: ...
   def RetrieveEntityPermissions(self, entity: ManagedEntity, inherited: bool) -> list[Permission]: ...
   def RetrieveAllPermissions(self) -> list[Permission]: ...
   def SetEntityPermissions(self, entity: ManagedEntity, permission: list[Permission]) -> NoReturn: ...
   def ResetEntityPermissions(self, entity: ManagedEntity, permission: list[Permission]) -> NoReturn: ...
   def RemoveEntityPermission(self, entity: ManagedEntity, user: str, isGroup: bool) -> NoReturn: ...
   def HasPrivilegeOnEntity(self, entity: ManagedEntity, sessionId: str, privId: list[str]) -> list[bool]: ...
   def HasPrivilegeOnEntities(self, entity: list[ManagedEntity], sessionId: str, privId: list[str]) -> list[EntityPrivilege]: ...
   def HasUserPrivilegeOnEntities(self, entities: list[ManagedObject], userName: str, privId: list[str]) -> list[EntityPrivilege]: ...
   def FetchUserPrivilegeOnEntities(self, entities: list[ManagedEntity], userName: str) -> list[UserPrivilegeResult]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ExtensibleManagedObject

from pyVmomi.vmodl import DynamicData

class CpuSchedulerSystem(ExtensibleManagedObject):
   class HyperThreadScheduleInfo(DynamicData):
      available: bool
      active: bool
      config: bool

   class CpuSchedulerInfo(DynamicData):
      class CpuSchedulerPolicyInfo(Enum):
         systemDefault: ClassVar['CpuSchedulerPolicyInfo'] = 'systemDefault'
         scav1: ClassVar['CpuSchedulerPolicyInfo'] = 'scav1'
         scav2: ClassVar['CpuSchedulerPolicyInfo'] = 'scav2'

      policy: str

   @property
   def cpuSchedulerInfo(self) -> Optional[CpuSchedulerInfo]: ...
   @property
   def hyperthreadInfo(self) -> Optional[HyperThreadScheduleInfo]: ...

   def EnableHyperThreading(self) -> NoReturn: ...
   def DisableHyperThreading(self) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.host import PhysicalNic
from pyVmomi.vim.host import VirtualNic

class IscsiManager(ManagedObject):
   class IscsiStatus(DynamicData):
      reason: list[MethodFault] = []

   class IscsiPortInfo(DynamicData):
      class PathStatus(Enum):
         notUsed: ClassVar['PathStatus'] = 'notUsed'
         active: ClassVar['PathStatus'] = 'active'
         standBy: ClassVar['PathStatus'] = 'standBy'
         lastActive: ClassVar['PathStatus'] = 'lastActive'

      vnicDevice: Optional[str] = None
      vnic: Optional[VirtualNic] = None
      pnicDevice: Optional[str] = None
      pnic: Optional[PhysicalNic] = None
      switchName: Optional[str] = None
      switchUuid: Optional[str] = None
      portgroupName: Optional[str] = None
      portgroupKey: Optional[str] = None
      portKey: Optional[str] = None
      opaqueNetworkId: Optional[str] = None
      opaqueNetworkType: Optional[str] = None
      opaqueNetworkName: Optional[str] = None
      externalId: Optional[str] = None
      complianceStatus: Optional[IscsiStatus] = None
      pathStatus: Optional[str] = None

   class IscsiDependencyEntity(DynamicData):
      pnicDevice: str
      vnicDevice: str
      vmhbaName: str

   class IscsiMigrationDependency(DynamicData):
      migrationAllowed: bool
      disallowReason: Optional[IscsiStatus] = None
      dependency: list[IscsiDependencyEntity] = []

   def QueryVnicStatus(self, vnicDevice: str) -> IscsiStatus: ...
   def QueryPnicStatus(self, pnicDevice: str) -> IscsiStatus: ...
   def QueryBoundVnics(self, iScsiHbaName: str) -> list[IscsiPortInfo]: ...
   def QueryCandidateNics(self, iScsiHbaName: str) -> list[IscsiPortInfo]: ...
   def BindVnic(self, iScsiHbaName: str, vnicDevice: str) -> NoReturn: ...
   def UnbindVnic(self, iScsiHbaName: str, vnicDevice: str, force: bool) -> NoReturn: ...
   def QueryMigrationDependencies(self, pnicDevice: list[str]) -> IscsiMigrationDependency: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import HostBusAdapter

from pyVmomi.vim.option import OptionDef
from pyVmomi.vim.option import OptionValue

class InternetScsiHba(HostBusAdapter):
   class ParamValue(OptionValue):
      isInherited: Optional[bool] = None

   class DiscoveryCapabilities(DynamicData):
      iSnsDiscoverySettable: bool
      slpDiscoverySettable: bool
      staticTargetDiscoverySettable: bool
      sendTargetsDiscoverySettable: bool

   class DiscoveryProperties(DynamicData):
      class ISnsDiscoveryMethod(Enum):
         isnsStatic: ClassVar['ISnsDiscoveryMethod'] = 'isnsStatic'
         isnsDhcp: ClassVar['ISnsDiscoveryMethod'] = 'isnsDhcp'
         isnsSlp: ClassVar['ISnsDiscoveryMethod'] = 'isnsSlp'

      class SlpDiscoveryMethod(Enum):
         slpDhcp: ClassVar['SlpDiscoveryMethod'] = 'slpDhcp'
         slpAutoUnicast: ClassVar['SlpDiscoveryMethod'] = 'slpAutoUnicast'
         slpAutoMulticast: ClassVar['SlpDiscoveryMethod'] = 'slpAutoMulticast'
         slpManual: ClassVar['SlpDiscoveryMethod'] = 'slpManual'

      iSnsDiscoveryEnabled: bool
      iSnsDiscoveryMethod: Optional[str] = None
      iSnsHost: Optional[str] = None
      slpDiscoveryEnabled: bool
      slpDiscoveryMethod: Optional[str] = None
      slpHost: Optional[str] = None
      staticTargetDiscoveryEnabled: bool
      sendTargetsDiscoveryEnabled: bool

   class ChapAuthenticationType(Enum):
      chapProhibited: ClassVar['ChapAuthenticationType'] = 'chapProhibited'
      chapDiscouraged: ClassVar['ChapAuthenticationType'] = 'chapDiscouraged'
      chapPreferred: ClassVar['ChapAuthenticationType'] = 'chapPreferred'
      chapRequired: ClassVar['ChapAuthenticationType'] = 'chapRequired'

   class AuthenticationCapabilities(DynamicData):
      chapAuthSettable: bool
      krb5AuthSettable: bool
      srpAuthSettable: bool
      spkmAuthSettable: bool
      mutualChapSettable: Optional[bool] = None
      targetChapSettable: Optional[bool] = None
      targetMutualChapSettable: Optional[bool] = None

   class AuthenticationProperties(DynamicData):
      chapAuthEnabled: bool
      chapName: Optional[str] = None
      chapSecret: Optional[str] = None
      chapAuthenticationType: Optional[str] = None
      chapInherited: Optional[bool] = None
      mutualChapName: Optional[str] = None
      mutualChapSecret: Optional[str] = None
      mutualChapAuthenticationType: Optional[str] = None
      mutualChapInherited: Optional[bool] = None

   class DigestType(Enum):
      digestProhibited: ClassVar['DigestType'] = 'digestProhibited'
      digestDiscouraged: ClassVar['DigestType'] = 'digestDiscouraged'
      digestPreferred: ClassVar['DigestType'] = 'digestPreferred'
      digestRequired: ClassVar['DigestType'] = 'digestRequired'

   class DigestCapabilities(DynamicData):
      headerDigestSettable: Optional[bool] = None
      dataDigestSettable: Optional[bool] = None
      targetHeaderDigestSettable: Optional[bool] = None
      targetDataDigestSettable: Optional[bool] = None

   class DigestProperties(DynamicData):
      headerDigestType: Optional[str] = None
      headerDigestInherited: Optional[bool] = None
      dataDigestType: Optional[str] = None
      dataDigestInherited: Optional[bool] = None

   class IPCapabilities(DynamicData):
      addressSettable: bool
      ipConfigurationMethodSettable: bool
      subnetMaskSettable: bool
      defaultGatewaySettable: bool
      primaryDnsServerAddressSettable: bool
      alternateDnsServerAddressSettable: bool
      ipv6Supported: Optional[bool] = None
      arpRedirectSettable: Optional[bool] = None
      mtuSettable: Optional[bool] = None
      hostNameAsTargetAddress: Optional[bool] = None
      nameAliasSettable: Optional[bool] = None
      ipv4EnableSettable: Optional[bool] = None
      ipv6EnableSettable: Optional[bool] = None
      ipv6PrefixLengthSettable: Optional[bool] = None
      ipv6PrefixLength: Optional[int] = None
      ipv6DhcpConfigurationSettable: Optional[bool] = None
      ipv6LinkLocalAutoConfigurationSettable: Optional[bool] = None
      ipv6RouterAdvertisementConfigurationSettable: Optional[bool] = None
      ipv6DefaultGatewaySettable: Optional[bool] = None
      ipv6MaxStaticAddressesSupported: Optional[int] = None

   class IscsiIpv6Address(DynamicData):
      class AddressConfigurationType(Enum):
         DHCP: ClassVar['AddressConfigurationType'] = 'DHCP'
         AutoConfigured: ClassVar['AddressConfigurationType'] = 'AutoConfigured'
         Static: ClassVar['AddressConfigurationType'] = 'Static'
         Other: ClassVar['AddressConfigurationType'] = 'Other'

      class IPv6AddressOperation(Enum):
         add: ClassVar['IPv6AddressOperation'] = 'add'
         remove: ClassVar['IPv6AddressOperation'] = 'remove'

      address: str
      prefixLength: int
      origin: str
      operation: Optional[str] = None

   class IPv6Properties(DynamicData):
      iscsiIpv6Address: list[IscsiIpv6Address] = []
      ipv6DhcpConfigurationEnabled: Optional[bool] = None
      ipv6LinkLocalAutoConfigurationEnabled: Optional[bool] = None
      ipv6RouterAdvertisementConfigurationEnabled: Optional[bool] = None
      ipv6DefaultGateway: Optional[str] = None

   class IPProperties(DynamicData):
      mac: Optional[str] = None
      address: Optional[str] = None
      dhcpConfigurationEnabled: bool
      subnetMask: Optional[str] = None
      defaultGateway: Optional[str] = None
      primaryDnsServerAddress: Optional[str] = None
      alternateDnsServerAddress: Optional[str] = None
      ipv6Address: Optional[str] = None
      ipv6SubnetMask: Optional[str] = None
      ipv6DefaultGateway: Optional[str] = None
      arpRedirectEnabled: Optional[bool] = None
      mtu: Optional[int] = None
      jumboFramesEnabled: Optional[bool] = None
      ipv4Enabled: Optional[bool] = None
      ipv6Enabled: Optional[bool] = None
      ipv6properties: Optional[IPv6Properties] = None

   class SendTarget(DynamicData):
      address: str
      port: Optional[int] = None
      authenticationProperties: Optional[AuthenticationProperties] = None
      digestProperties: Optional[DigestProperties] = None
      supportedAdvancedOptions: list[OptionDef] = []
      advancedOptions: list[ParamValue] = []
      parent: Optional[str] = None

   class StaticTarget(DynamicData):
      class TargetDiscoveryMethod(Enum):
         staticMethod: ClassVar['TargetDiscoveryMethod'] = 'staticMethod'
         sendTargetMethod: ClassVar['TargetDiscoveryMethod'] = 'sendTargetMethod'
         slpMethod: ClassVar['TargetDiscoveryMethod'] = 'slpMethod'
         isnsMethod: ClassVar['TargetDiscoveryMethod'] = 'isnsMethod'
         unknownMethod: ClassVar['TargetDiscoveryMethod'] = 'unknownMethod'

      address: str
      port: Optional[int] = None
      iScsiName: str
      discoveryMethod: Optional[str] = None
      authenticationProperties: Optional[AuthenticationProperties] = None
      digestProperties: Optional[DigestProperties] = None
      supportedAdvancedOptions: list[OptionDef] = []
      advancedOptions: list[ParamValue] = []
      parent: Optional[str] = None

   class TargetSet(DynamicData):
      staticTargets: list[StaticTarget] = []
      sendTargets: list[SendTarget] = []

   class NetworkBindingSupportType(Enum):
      notsupported: ClassVar['NetworkBindingSupportType'] = 'notsupported'
      optional: ClassVar['NetworkBindingSupportType'] = 'optional'
      required: ClassVar['NetworkBindingSupportType'] = 'required'

   isSoftwareBased: bool
   canBeDisabled: Optional[bool] = None
   networkBindingSupport: Optional[NetworkBindingSupportType] = None
   discoveryCapabilities: DiscoveryCapabilities
   discoveryProperties: DiscoveryProperties
   authenticationCapabilities: AuthenticationCapabilities
   authenticationProperties: AuthenticationProperties
   digestCapabilities: Optional[DigestCapabilities] = None
   digestProperties: Optional[DigestProperties] = None
   ipCapabilities: IPCapabilities
   ipProperties: IPProperties
   supportedAdvancedOptions: list[OptionDef] = []
   advancedOptions: list[ParamValue] = []
   iScsiName: str
   iScsiAlias: Optional[str] = None
   configuredSendTarget: list[SendTarget] = []
   configuredStaticTarget: list[StaticTarget] = []
   maxSpeedMb: Optional[int] = None
   currentSpeedMb: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import SoftwarePackage

class ImageConfigManager(ManagedObject):
   class AcceptanceLevel(Enum):
      vmware_certified: ClassVar['AcceptanceLevel'] = 'vmware_certified'
      vmware_accepted: ClassVar['AcceptanceLevel'] = 'vmware_accepted'
      partner: ClassVar['AcceptanceLevel'] = 'partner'
      community: ClassVar['AcceptanceLevel'] = 'community'

   class ImageProfileSummary(DynamicData):
      name: str
      vendor: str

   def QueryHostAcceptanceLevel(self) -> str: ...
   def QueryHostImageProfile(self) -> ImageProfileSummary: ...
   def UpdateAcceptanceLevel(self, newAcceptanceLevel: str) -> NoReturn: ...
   def FetchSoftwarePackages(self) -> list[SoftwarePackage]: ...
   def InstallDate(self) -> datetime: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

from pyVmomi.vim.vsan.host import DataInTransitEncryptionInfo

class VsanDitEncryptionHealthSummary(DynamicData):
   hostname: Optional[str] = None
   health: Optional[str] = None
   reason: Optional[LocalizableMessage] = None
   ditEncryptionInfo: Optional[DataInTransitEncryptionInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanObjectSpaceSummary
from pyVmomi.vim.cluster import VsanSpaceUsageDetailResult
from pyVmomi.vim.cluster import VsanWhatifCapacity

from pyVmomi.vim.vsan import DataEfficiencyCapacityState
from pyVmomi.vim.vsan import VsanHealthThreshold
from pyVmomi.vim.vsan import VsanSpaceEfficiencyRatio

class VsanSpaceUsage(DynamicData):
   totalCapacityB: long
   freeCapacityB: Optional[long] = None
   spaceOverview: Optional[VsanObjectSpaceSummary] = None
   spaceDetail: Optional[VsanSpaceUsageDetailResult] = None
   efficientCapacity: Optional[DataEfficiencyCapacityState] = None
   whatifCapacities: list[VsanWhatifCapacity] = []
   uncommittedB: Optional[long] = None
   capacityHealthThreshold: Optional[VsanHealthThreshold] = None
   spaceEfficiencyRatio: Optional[VsanSpaceEfficiencyRatio] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .CloneSpec import CloneSpec as CloneSpec
from .EntityConfigInfo import EntityConfigInfo as EntityConfigInfo
from .IPAssignmentInfo import IPAssignmentInfo as IPAssignmentInfo
from .IpPool import IpPool as IpPool
from .OvfSectionInfo import OvfSectionInfo as OvfSectionInfo
from .OvfSectionSpec import OvfSectionSpec as OvfSectionSpec
from .ProductInfo import ProductInfo as ProductInfo
from .ProductSpec import ProductSpec as ProductSpec
from .PropertyInfo import PropertyInfo as PropertyInfo
from .PropertySpec import PropertySpec as PropertySpec
from .VAppConfigInfo import VAppConfigInfo as VAppConfigInfo
from .VAppConfigSpec import VAppConfigSpec as VAppConfigSpec
from .VAppImportSpec import VAppImportSpec as VAppImportSpec
from .VmConfigInfo import VmConfigInfo as VmConfigInfo
from .VmConfigSpec import VmConfigSpec as VmConfigSpec



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ExtendedDescription

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

class ProfileMetadata(DynamicData):
   class ProfileSortSpec(DynamicData):
      policyId: str
      parameter: str

   class ProfileOperationMessage(DynamicData):
      operationName: str
      message: LocalizableMessage

   key: type
   profileTypeName: Optional[str] = None
   description: Optional[ExtendedDescription] = None
   sortSpec: list[ProfileSortSpec] = []
   profileCategory: Optional[str] = None
   profileComponent: Optional[str] = None
   operationMessages: list[ProfileOperationMessage] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanHealthThreshold
from pyVmomi.vim.vsan import VsanHistoricalHealthConfig

class VsanHealthConfigSpec(DynamicData):
   healthCheckThresholdSpec: list[VsanHealthThreshold] = []
   historicalHealthConfig: Optional[VsanHistoricalHealthConfig] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.event import DatacenterEventArgument
from pyVmomi.vim.event import DatastoreEventArgument
from pyVmomi.vim.event import HostEventArgument
from pyVmomi.vim.event import VmRelocateSpecEvent

class VmBeingRelocatedEvent(VmRelocateSpecEvent):
   destHost: HostEventArgument
   destDatacenter: Optional[DatacenterEventArgument] = None
   destDatastore: Optional[DatastoreEventArgument] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanIscsiTargetServiceDefaultConfigSpec

from pyVmomi.vim.vsan import VipConfigSpec

class VsanIscsiTargetServiceConfig(DynamicData):
   defaultConfig: Optional[VsanIscsiTargetServiceDefaultConfigSpec] = None
   enabled: Optional[bool] = None
   vipConfigs: list[VipConfigSpec] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Folder
from pyVmomi.vim import StorageResourceManager

from pyVmomi.vmodl import DynamicData

class StoragePod(Folder):
   class Summary(DynamicData):
      name: str
      capacity: long
      freeSpace: long

   @property
   def summary(self) -> Optional[Summary]: ...
   @property
   def podStorageDrsEntry(self) -> Optional[StorageResourceManager.PodStorageDrsEntry]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import BIOSInfo
from pyVmomi.vim.host import CpuIdInfo
from pyVmomi.vim.host import CpuInfo
from pyVmomi.vim.host import CpuPackage
from pyVmomi.vim.host import CpuPowerManagementInfo
from pyVmomi.vim.host import DvxClass
from pyVmomi.vim.host import MemoryTierInfo
from pyVmomi.vim.host import NumaInfo
from pyVmomi.vim.host import PciDevice
from pyVmomi.vim.host import PersistentMemoryInfo
from pyVmomi.vim.host import ReliableMemoryInfo
from pyVmomi.vim.host import SevInfo
from pyVmomi.vim.host import SgxInfo
from pyVmomi.vim.host import SystemInfo
from pyVmomi.vim.host import TdxInfo

class HardwareInfo(DynamicData):
   systemInfo: SystemInfo
   cpuPowerManagementInfo: Optional[CpuPowerManagementInfo] = None
   cpuInfo: CpuInfo
   cpuPkg: list[CpuPackage] = []
   memorySize: long
   numaInfo: Optional[NumaInfo] = None
   smcPresent: bool
   pciDevice: list[PciDevice] = []
   dvxClasses: list[DvxClass] = []
   cpuFeature: list[CpuIdInfo] = []
   biosInfo: Optional[BIOSInfo] = None
   reliableMemoryInfo: Optional[ReliableMemoryInfo] = None
   persistentMemoryInfo: Optional[PersistentMemoryInfo] = None
   sgxInfo: Optional[SgxInfo] = None
   sevInfo: Optional[SevInfo] = None
   memoryTieringType: Optional[str] = None
   memoryTierInfo: list[MemoryTierInfo] = []
   tdxInfo: Optional[TdxInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

from pyVmomi.vim.cluster import Action

class Recommendation(DynamicData):
   class RecommendationType(Enum):
      V1: ClassVar['RecommendationType'] = 'V1'

   class ReasonCode(Enum):
      fairnessCpuAvg: ClassVar['ReasonCode'] = 'fairnessCpuAvg'
      fairnessMemAvg: ClassVar['ReasonCode'] = 'fairnessMemAvg'
      jointAffin: ClassVar['ReasonCode'] = 'jointAffin'
      antiAffin: ClassVar['ReasonCode'] = 'antiAffin'
      hostMaint: ClassVar['ReasonCode'] = 'hostMaint'
      enterStandby: ClassVar['ReasonCode'] = 'enterStandby'
      reservationCpu: ClassVar['ReasonCode'] = 'reservationCpu'
      reservationMem: ClassVar['ReasonCode'] = 'reservationMem'
      powerOnVm: ClassVar['ReasonCode'] = 'powerOnVm'
      powerSaving: ClassVar['ReasonCode'] = 'powerSaving'
      increaseCapacity: ClassVar['ReasonCode'] = 'increaseCapacity'
      checkResource: ClassVar['ReasonCode'] = 'checkResource'
      unreservedCapacity: ClassVar['ReasonCode'] = 'unreservedCapacity'
      colocateCommunicatingVM: ClassVar['ReasonCode'] = 'colocateCommunicatingVM'
      balanceNetworkBandwidthUsage: ClassVar['ReasonCode'] = 'balanceNetworkBandwidthUsage'
      vmHostHardAffinity: ClassVar['ReasonCode'] = 'vmHostHardAffinity'
      vmHostSoftAffinity: ClassVar['ReasonCode'] = 'vmHostSoftAffinity'
      increaseAllocation: ClassVar['ReasonCode'] = 'increaseAllocation'
      balanceDatastoreSpaceUsage: ClassVar['ReasonCode'] = 'balanceDatastoreSpaceUsage'
      balanceDatastoreIOLoad: ClassVar['ReasonCode'] = 'balanceDatastoreIOLoad'
      balanceDatastoreIOPSReservation: ClassVar['ReasonCode'] = 'balanceDatastoreIOPSReservation'
      datastoreMaint: ClassVar['ReasonCode'] = 'datastoreMaint'
      virtualDiskJointAffin: ClassVar['ReasonCode'] = 'virtualDiskJointAffin'
      virtualDiskAntiAffin: ClassVar['ReasonCode'] = 'virtualDiskAntiAffin'
      datastoreSpaceOutage: ClassVar['ReasonCode'] = 'datastoreSpaceOutage'
      storagePlacement: ClassVar['ReasonCode'] = 'storagePlacement'
      iolbDisabledInternal: ClassVar['ReasonCode'] = 'iolbDisabledInternal'
      xvmotionPlacement: ClassVar['ReasonCode'] = 'xvmotionPlacement'
      networkBandwidthReservation: ClassVar['ReasonCode'] = 'networkBandwidthReservation'
      hostInDegradation: ClassVar['ReasonCode'] = 'hostInDegradation'
      hostExitDegradation: ClassVar['ReasonCode'] = 'hostExitDegradation'
      maxVmsConstraint: ClassVar['ReasonCode'] = 'maxVmsConstraint'
      ftConstraints: ClassVar['ReasonCode'] = 'ftConstraints'
      vmHostAffinityPolicy: ClassVar['ReasonCode'] = 'vmHostAffinityPolicy'
      vmHostAntiAffinityPolicy: ClassVar['ReasonCode'] = 'vmHostAntiAffinityPolicy'
      vmAntiAffinityPolicy: ClassVar['ReasonCode'] = 'vmAntiAffinityPolicy'
      balanceVsanUsage: ClassVar['ReasonCode'] = 'balanceVsanUsage'
      ahPlacementOptimization: ClassVar['ReasonCode'] = 'ahPlacementOptimization'
      vmxUpgrade: ClassVar['ReasonCode'] = 'vmxUpgrade'

   key: str
   type: str
   time: datetime
   rating: int
   reason: str
   reasonText: str
   warningText: Optional[str] = None
   warningDetails: Optional[LocalizableMessage] = None
   prerequisite: list[str] = []
   action: list[Action] = []
   target: Optional[ManagedObject] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ServiceLocator

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import ProfileSpec

from pyVmomi.vim.vslm import CreateSpec
from pyVmomi.vim.vslm import DiskCryptoSpec

class MigrateSpec(DynamicData):
   backingSpec: CreateSpec.BackingSpec
   profile: list[ProfileSpec] = []
   consolidate: Optional[bool] = None
   disksCrypto: Optional[DiskCryptoSpec] = None
   service: Optional[ServiceLocator] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import LACPInfo
from pyVmomi.vim.host import PnicTSOInfo
from pyVmomi.vim.host import VirtualNic

class VsanNetworkDiagnosticsHealthInfo(DynamicData):
   vnicInfo: list[VirtualNic] = []
   pnicTSOInfo: list[PnicTSOInfo] = []
   LACPInfo: list[LACPInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ManagedEntity

from pyVmomi.vim.alarm import Alarm
from pyVmomi.vim.alarm import AlarmDescription
from pyVmomi.vim.alarm import AlarmExpression
from pyVmomi.vim.alarm import AlarmFilterSpec
from pyVmomi.vim.alarm import AlarmSpec
from pyVmomi.vim.alarm import AlarmState

class AlarmManager(ManagedObject):
   @property
   def defaultExpression(self) -> list[AlarmExpression]: ...
   @property
   def description(self) -> AlarmDescription: ...

   def Create(self, entity: ManagedEntity, spec: AlarmSpec) -> Alarm: ...
   def GetAlarm(self, entity: Optional[ManagedEntity]) -> list[Alarm]: ...
   def GetAlarmActionsEnabled(self, entity: ManagedEntity) -> bool: ...
   def SetAlarmActionsEnabled(self, entity: ManagedEntity, enabled: bool) -> NoReturn: ...
   def GetAlarmState(self, entity: ManagedEntity) -> list[AlarmState]: ...
   def AcknowledgeAlarm(self, alarm: Alarm, entity: ManagedEntity) -> NoReturn: ...
   def ClearTriggeredAlarms(self, filter: AlarmFilterSpec) -> NoReturn: ...
   def DisableAlarm(self, alarm: Alarm, entity: ManagedEntity) -> NoReturn: ...
   def EnableAlarm(self, alarm: Alarm, entity: ManagedEntity) -> NoReturn: ...



#############################################################
# Copyright (c) 2005-2023 VMware, Inc.
#############################################################

# @file task.py
# @brief Task functions
#
# This module provies synchronization of client/server operations
# since many VIM operations return 'tasks' which can have
# varying completion times.
"""
Task functions

This module provies synchronization of client/server operations since
many VIM operations return 'tasks' which can have varying completion
times.
"""

__author__ = 'VMware, Inc'

from pyVmomi import vmodl, vim

import time


#
# @brief Exception class to represent when task is blocked (e.g.:
# waiting for an answer to a question.
#
class TaskBlocked(Exception):
    """
    Exception class to represent when task is blocked
    e.g.: waiting for an answer to a question
    """
    pass


#
# TaskUpdates
#     verbose information about task progress
#
def TaskUpdatesVerbose(task, progress):
    info = task.info
    if isinstance(info.progress, int):
        if not isinstance(progress, str):
            progress = '{:.0f}% ({})'.format(info.progress, info.state)
        print('Task %s (key:%s, desc:%s) - %s' %
              (info.name.info.name, info.key, info.description, progress))


globalTaskUpdate = None


def SetTasksVerbose(verbose=True):
    global globalTaskUpdate
    if verbose:
        globalTaskUpdate = TaskUpdatesVerbose
    else:
        globalTaskUpdate = None


#
# @param raiseOnError [in] Any exception thrown is thrown up to the caller if
# raiseOnError is set to true
# @param si [in] ServiceInstance to use. If set to None, use the default one.
# @param pc [in] property collector to use else retrieve one from cache
# @param maxWaitTime [in] The maximum amount of time the task is allowed to
# run. Throws an exception if raiseOnError is True.
# @param onProgressUpdate [in] callable to call with task progress updates.
#    For example:
#
#    def OnTaskProgressUpdate(task, percentDone):
#       sys.stderr.write('# Task {}: {:.0f}% complete ...\n'
#                        .format(task, percentDone))
#
# Given a task object and a service instance, wait for the task completion
#
# @return state as either "success" or "error". To look at any errors, the
# user should reexamine the task object.
#
# NOTE: This is a blocking call.
#
def WaitForTask(task,
                raiseOnError=True,
                si=None,
                pc=None,
                maxWaitTime=None,
                onProgressUpdate=None,
                log=None,
                getAllUpdates=False):
    """
    Wait for task to complete.

    @type  raiseOnError      : bool
    @param raiseOnError      : Any exception thrown is thrown up to the caller
                                if raiseOnError is set to true.
    @type  si                : ManagedObjectReference to a ServiceInstance.
    @param si                : ServiceInstance to use. If None, use the
                                information from the task.
    @type  pc                : ManagedObjectReference to a PropertyCollector.
    @param pc                : Property collector to use. If None, get it from
                                the ServiceInstance.
    @type  maxWaitTime       : numeric value
    @param maxWaitTime       : The maximum amount of time the task is allowed to
                                run. Throws an exception if raiseOnError is True.
    @type  onProgressUpdate  : callable
    @param onProgressUpdate  : The callable to call with task progress updates.
    @type  log               : Optional logger.
    @param log               : Logging.
    @type  getAllUpdates     : Optional bool value. Default is False.
    @param getAllUpdates     : Get all updates for the task.

        For example::

            def OnTaskProgressUpdate(task, percentDone):
                print 'Task {} is {:.0f}% complete.'.format(task, percentDone)
    """

    if pc is None:
        if si is None: si = vim.ServiceInstance("ServiceInstance", task._stub)
        pc = si.content.propertyCollector

    progressUpdater = ProgressUpdater(task, onProgressUpdate, getAllUpdates)
    progressUpdater.Update('created')

    filter = CreateFilter(pc, task)

    version, state = None, None

    if maxWaitTime:
        waitTime = maxWaitTime + time.time()

    # Loop looking for updates till the state moves to a completed state.
    while state not in (vim.TaskInfo.State.success, vim.TaskInfo.State.error):
        try:
            version, state = GetTaskStatus(task, version, pc)
            progressUpdater.UpdateIfNeeded()

            if maxWaitTime and waitTime < time.time():
                err = "Task exceeded timeout of %d seconds" % maxWaitTime
                progressUpdater.Update(err)
                if raiseOnError is True:
                    raise Exception(err)
                break
        except vmodl.fault.ManagedObjectNotFound as e:
            print("Task object has been deleted: %s" % e.obj)
            break

    DestroyFilter(filter)

    info = task.info
    if state == "error":
        progressUpdater.Update("error: %s" % info.error)
        if raiseOnError:
            raise info.error
        else:
            _LogMsg(log, "Task reported error: %s" % info.error)
    elif state == "success":
        progressUpdater.Update('completed')
    elif state == "queued":
        _LogMsg(log, "Task reports as queued: %s" % info)
        progressUpdater.UpdateIfNeeded()
    else:  # state = running
        _LogMsg(log, "Task reports as still running: %s" % info)
        progressUpdater.UpdateIfNeeded()

    return state


# Wait for multiple tasks to complete
#  See WaitForTask for detail
#
#  Difference: WaitForTasks won't return the state of tasks. User can check
#  tasks state directly with task.info.state
#
#  TODO: Did not check for question pending
def WaitForTasks(tasks,
                 raiseOnError=True,
                 si=None,
                 pc=None,
                 onProgressUpdate=None,
                 results=None,
                 getAllUpdates=False):
    """
    Wait for multiple tasks to complete. Much faster than calling WaitForTask
    N times.
    """

    if not tasks:
        return

    if si is None: si = vim.ServiceInstance("ServiceInstance", tasks[0]._stub)
    if pc is None: pc = si.content.propertyCollector
    if results is None: results = []

    progressUpdaters = {}
    for task in tasks:
        progressUpdater = ProgressUpdater(task, onProgressUpdate, getAllUpdates)
        progressUpdater.Update('created')
        progressUpdaters[str(task)] = progressUpdater

    filter = CreateTasksFilter(pc, tasks)

    try:
        version, state = None, None

        # Loop looking for updates till the state moves to a completed state.
        while len(progressUpdaters):
            update = pc.WaitForUpdates(version)
            for filterSet in update.filterSet:
                for objSet in filterSet.objectSet:
                    task = objSet.obj
                    taskId = str(task)
                    for change in objSet.changeSet:
                        if change.name == 'info':
                            state = change.val.state
                        elif change.name == 'info.state':
                            state = change.val
                        else:
                            continue

                        progressUpdater = progressUpdaters.get(taskId)
                        if not progressUpdater:
                            continue

                        if state == vim.TaskInfo.State.success:
                            progressUpdater.Update('completed')
                            progressUpdaters.pop(taskId)
                            # cache the results, as task objects could expire if one
                            # of the tasks take a longer time to complete
                            results.append(task.info.result)
                        elif state == vim.TaskInfo.State.error:
                            err = task.info.error
                            progressUpdater.Update('error: %s' % str(err))
                            if raiseOnError:
                                try:
                                    raise err
                                finally:
                                    del err
                            else:
                                print("Task %s reported error: %s" %
                                      (taskId, str(err)))
                                progressUpdaters.pop(taskId)
                        else:
                            if onProgressUpdate:
                                progressUpdater.UpdateIfNeeded()
            # Move to next version
            version = update.version
    finally:
        if filter:
            DestroyFilter(filter)
    return


def GetTaskStatus(task, version, pc):
    update = pc.WaitForUpdates(version)
    info = task.info
    state = info.state

    if (state == 'running' and info.name is not None and info.name.info.name
            not in ['Destroy', 'Relocate', 'CreateVm']):
        CheckForQuestionPending(info)

    return update.version, state


def CreateFilter(pc, task):
    """ Create property collector filter for task """
    return CreateTasksFilter(pc, [task])


def CreateTasksFilter(pc, tasks):
    """ Create property collector filter for tasks """
    if not tasks:
        return None

    # First create the object specification as the task object.
    objspecs = [
        vmodl.query.PropertyCollector.ObjectSpec(obj=task) for task in tasks
    ]

    # Next, create the property specification as the state.
    propspec = vmodl.query.PropertyCollector.PropertySpec(type=vim.Task,
                                                          pathSet=[],
                                                          all=True)

    # Create a filter spec with the specified object and property spec.
    filterspec = vmodl.query.PropertyCollector.FilterSpec()
    filterspec.objectSet = objspecs
    filterspec.propSet = [propspec]

    # Create the filter
    return pc.CreateFilter(filterspec, True)


def DestroyFilter(filter):
    try:
        filter.Destroy()
    except vmodl.fault.ManagedObjectNotFound:
        pass


def CheckForQuestionPending(info):
    """ Check to see if VM needs to ask a question, throw exception """

    vm = info.entity
    if vm is not None and isinstance(vm, vim.VirtualMachine):
        qst = vm.runtime.question
        if qst is not None:
            raise TaskBlocked("Task blocked, User Intervention required")


def _LogMsg(log, message):
    """Helper logging a message with logger or print depending on the flag."""
    if log:
        log(message)
    else:
        print(message)


#
# @brief Class that keeps track of task percentage complete and calls
# a provided callback when it changes.
#
class ProgressUpdater(object):
    """
    Class that keeps track of task percentage complete and calls a
    provided callback when it changes.
    """
    def __init__(self, task, onProgressUpdate, getAllUpdates=False):
        self.task = task
        self.onProgressUpdate = onProgressUpdate
        self.getAllUpdates = getAllUpdates
        self.prevProgress = 0
        self.progress = 0

    def Update(self, state):
        global globalTaskUpdate
        taskUpdate = globalTaskUpdate
        if self.onProgressUpdate:
            taskUpdate = self.onProgressUpdate
        if taskUpdate:
            taskUpdate(self.task, state)

    def UpdateIfNeeded(self):
        self.progress = self.task.info.progress

        if self.getAllUpdates or self.progress != self.prevProgress:
            self.Update(self.progress)

        self.prevProgress = self.progress



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long
from pyVmomi.VmomiSupport import short

from pyVmomi.vim import AboutInfo
from pyVmomi.vim import CustomFieldsManager
from pyVmomi.vim import Datastore
from pyVmomi.vim import HostSystem
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Network

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import FeatureVersionInfo
from pyVmomi.vim.host import RuntimeInfo
from pyVmomi.vim.host import SystemIdentificationInfo
from pyVmomi.vim.host import TpmAttestationInfo
from pyVmomi.vim.host import TrustAuthorityAttestationInfo

class Summary(DynamicData):
   class HardwareSummary(DynamicData):
      vendor: str
      model: str
      family: Optional[str] = None
      uuid: str
      otherIdentifyingInfo: list[SystemIdentificationInfo] = []
      memorySize: long
      cpuModel: str
      cpuMhz: int
      numCpuPkgs: short
      numCpuCores: short
      numCpuThreads: short
      numNics: int
      numHBAs: int

   class QuickStats(DynamicData):
      overallCpuUsage: Optional[int] = None
      overallMemoryUsage: Optional[int] = None
      distributedCpuFairness: Optional[int] = None
      distributedMemoryFairness: Optional[int] = None
      availablePMemCapacity: Optional[int] = None
      uptime: Optional[int] = None

   class ConfigSummary(DynamicData):
      name: str
      port: int
      sslThumbprint: Optional[str] = None
      sslCertificate: Optional[str] = None
      product: Optional[AboutInfo] = None
      vmotionEnabled: bool
      faultToleranceEnabled: bool
      featureVersion: list[FeatureVersionInfo] = []
      agentVmDatastore: Optional[Datastore] = None
      agentVmNetwork: Optional[Network] = None

   class GatewaySummary(DynamicData):
      gatewayType: str
      gatewayId: str

   host: Optional[HostSystem] = None
   hardware: Optional[HardwareSummary] = None
   runtime: Optional[RuntimeInfo] = None
   config: ConfigSummary
   quickStats: QuickStats
   overallStatus: ManagedEntity.Status
   rebootRequired: bool
   customValue: list[CustomFieldsManager.Value] = []
   managementServerIp: Optional[str] = None
   maxEVCModeKey: Optional[str] = None
   currentEVCModeKey: Optional[str] = None
   currentEVCGraphicsModeKey: Optional[str] = None
   gateway: Optional[GatewaySummary] = None
   tpmAttestation: Optional[TpmAttestationInfo] = None
   trustAuthorityAttestationInfos: list[TrustAuthorityAttestationInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.fault import VmFaultToleranceIssue

class FtIssuesOnHost(VmFaultToleranceIssue):
   class HostSelectionType(Enum):
      user: ClassVar['HostSelectionType'] = 'user'
      vc: ClassVar['HostSelectionType'] = 'vc'
      drs: ClassVar['HostSelectionType'] = 'drs'

   host: HostSystem
   hostName: str
   errors: list[MethodFault] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class IpRouteConfigInfo(DynamicData):
   class Gateway(DynamicData):
      ipAddress: Optional[str] = None
      device: Optional[str] = None

   class IpRoute(DynamicData):
      network: str
      prefixLength: int
      gateway: Gateway

   ipRoute: list[IpRoute] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm.guest import GuestAuthentication

class FileManager(ManagedObject):
   class FileAttributes(DynamicData):
      modificationTime: Optional[datetime] = None
      accessTime: Optional[datetime] = None
      symlinkTarget: Optional[str] = None

   class PosixFileAttributes(FileAttributes):
      ownerId: Optional[int] = None
      groupId: Optional[int] = None
      permissions: Optional[long] = None

   class WindowsFileAttributes(FileAttributes):
      hidden: Optional[bool] = None
      readOnly: Optional[bool] = None
      createTime: Optional[datetime] = None

   class FileInfo(DynamicData):
      class FileType(Enum):
         file: ClassVar['FileType'] = 'file'
         directory: ClassVar['FileType'] = 'directory'
         symlink: ClassVar['FileType'] = 'symlink'

      path: str
      type: str
      size: long
      attributes: FileAttributes

   class ListFileInfo(DynamicData):
      files: list[FileInfo] = []
      remaining: int

   class FileTransferInformation(DynamicData):
      attributes: FileAttributes
      size: long
      url: str

   def MakeDirectory(self, vm: VirtualMachine, auth: GuestAuthentication, directoryPath: str, createParentDirectories: bool) -> NoReturn: ...
   def DeleteFile(self, vm: VirtualMachine, auth: GuestAuthentication, filePath: str) -> NoReturn: ...
   def DeleteDirectory(self, vm: VirtualMachine, auth: GuestAuthentication, directoryPath: str, recursive: bool) -> NoReturn: ...
   def MoveDirectory(self, vm: VirtualMachine, auth: GuestAuthentication, srcDirectoryPath: str, dstDirectoryPath: str) -> NoReturn: ...
   def MoveFile(self, vm: VirtualMachine, auth: GuestAuthentication, srcFilePath: str, dstFilePath: str, overwrite: bool) -> NoReturn: ...
   def CreateTemporaryFile(self, vm: VirtualMachine, auth: GuestAuthentication, prefix: str, suffix: str, directoryPath: Optional[str]) -> str: ...
   def CreateTemporaryDirectory(self, vm: VirtualMachine, auth: GuestAuthentication, prefix: str, suffix: str, directoryPath: Optional[str]) -> str: ...
   def ListFiles(self, vm: VirtualMachine, auth: GuestAuthentication, filePath: str, index: Optional[int], maxResults: Optional[int], matchPattern: Optional[str]) -> ListFileInfo: ...
   def ChangeFileAttributes(self, vm: VirtualMachine, auth: GuestAuthentication, guestFilePath: str, fileAttributes: FileAttributes) -> NoReturn: ...
   def InitiateFileTransferFromGuest(self, vm: VirtualMachine, auth: GuestAuthentication, guestFilePath: str) -> FileTransferInformation: ...
   def InitiateFileTransferToGuest(self, vm: VirtualMachine, auth: GuestAuthentication, guestFilePath: str, fileAttributes: FileAttributes, fileSize: long, overwrite: bool) -> str: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanClusterWhatifHostFailuresResult

from pyVmomi.vim.host import VsanLimitHealthResult

class VsanClusterLimitHealthResult(DynamicData):
   issueFound: bool
   componentLimitHealth: str
   diskFreeSpaceHealth: str
   rcFreeReservationHealth: str
   hostResults: list[VsanLimitHealthResult] = []
   whatifHostFailures: list[VsanClusterWhatifHostFailuresResult] = []
   hostsCommFailure: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.fault import ReplicationFault

class ReplicationVmFault(ReplicationFault):
   class ReasonForFault(Enum):
      notConfigured: ClassVar['ReasonForFault'] = 'notConfigured'
      poweredOff: ClassVar['ReasonForFault'] = 'poweredOff'
      suspended: ClassVar['ReasonForFault'] = 'suspended'
      poweredOn: ClassVar['ReasonForFault'] = 'poweredOn'
      offlineReplicating: ClassVar['ReasonForFault'] = 'offlineReplicating'
      invalidState: ClassVar['ReasonForFault'] = 'invalidState'
      invalidInstanceId: ClassVar['ReasonForFault'] = 'invalidInstanceId'
      closeDiskError: ClassVar['ReasonForFault'] = 'closeDiskError'
      groupExist: ClassVar['ReasonForFault'] = 'groupExist'

   reason: str
   state: Optional[str] = None
   instanceId: Optional[str] = None
   vm: VirtualMachine



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ElementDescription

from pyVmomi.vmodl import DynamicData

class SystemIdentificationInfo(DynamicData):
   class Identifier(Enum):
      AssetTag: ClassVar['Identifier'] = 'AssetTag'
      ServiceTag: ClassVar['Identifier'] = 'ServiceTag'
      OemSpecificString: ClassVar['Identifier'] = 'OemSpecificString'
      EnclosureSerialNumberTag: ClassVar['Identifier'] = 'EnclosureSerialNumberTag'
      SerialNumberTag: ClassVar['Identifier'] = 'SerialNumberTag'

   identifierValue: str
   identifierType: ElementDescription



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import provider as provider

from .CapabilityBasedProfile import CapabilityBasedProfile as CapabilityBasedProfile
from .CapabilityBasedProfileCreateSpec import CapabilityBasedProfileCreateSpec as CapabilityBasedProfileCreateSpec
from .CapabilityBasedProfileUpdateSpec import CapabilityBasedProfileUpdateSpec as CapabilityBasedProfileUpdateSpec
from .CapabilityConstraints import CapabilityConstraints as CapabilityConstraints
from .DataServiceToPoliciesMap import DataServiceToPoliciesMap as DataServiceToPoliciesMap
from .DefaultCapabilityBasedProfile import DefaultCapabilityBasedProfile as DefaultCapabilityBasedProfile
from .DefaultProfileInfo import DefaultProfileInfo as DefaultProfileInfo
from .Profile import Profile as Profile
from .ProfileId import ProfileId as ProfileId
from .ProfileManager import ProfileManager as ProfileManager
from .ProfileOperationOutcome import ProfileOperationOutcome as ProfileOperationOutcome
from .ProfileType import ProfileType as ProfileType
from .QueryProfileResult import QueryProfileResult as QueryProfileResult
from .ResourceType import ResourceType as ResourceType
from .ResourceTypeEnum import ResourceTypeEnum as ResourceTypeEnum
from .SubProfileCapabilityConstraints import SubProfileCapabilityConstraints as SubProfileCapabilityConstraints



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import cluster as cluster
from . import host as host
from . import upgradesystem as upgradesystem

from .ActiveDirectoryServerConfig import ActiveDirectoryServerConfig as ActiveDirectoryServerConfig
from .AdvancedDatastoreConfig import AdvancedDatastoreConfig as AdvancedDatastoreConfig
from .CapacityReservationInfo import CapacityReservationInfo as CapacityReservationInfo
from .CapacityReservationState import CapacityReservationState as CapacityReservationState
from .ClientDatastoreConfig import ClientDatastoreConfig as ClientDatastoreConfig
from .ClusterConfigPrecheckItem import ClusterConfigPrecheckItem as ClusterConfigPrecheckItem
from .ClusterRuntimeInfo import ClusterRuntimeInfo as ClusterRuntimeInfo
from .CompatibilityCheckResult import CompatibilityCheckResult as CompatibilityCheckResult
from .ConfigInfoEx import ConfigInfoEx as ConfigInfoEx
from .DataEfficiencyCapacityState import DataEfficiencyCapacityState as DataEfficiencyCapacityState
from .DataEfficiencyConfig import DataEfficiencyConfig as DataEfficiencyConfig
from .DataEfficiencyConfigEx import DataEfficiencyConfigEx as DataEfficiencyConfigEx
from .DataEncryptionConfig import DataEncryptionConfig as DataEncryptionConfig
from .DataInTransitEncryptionConfig import DataInTransitEncryptionConfig as DataInTransitEncryptionConfig
from .DatastoreConfig import DatastoreConfig as DatastoreConfig
from .DatastoreSourcePrecheckItem import DatastoreSourcePrecheckItem as DatastoreSourcePrecheckItem
from .DatastoreSourcePrecheckResult import DatastoreSourcePrecheckResult as DatastoreSourcePrecheckResult
from .DatastoreSpec import DatastoreSpec as DatastoreSpec
from .DefaultDatastorePolicySelectionInfo import DefaultDatastorePolicySelectionInfo as DefaultDatastorePolicySelectionInfo
from .DirectoryServerConfig import DirectoryServerConfig as DirectoryServerConfig
from .DiskClaimConfiguration import DiskClaimConfiguration as DiskClaimConfiguration
from .DiskDataEvacuationResourceCheckTaskDetails import DiskDataEvacuationResourceCheckTaskDetails as DiskDataEvacuationResourceCheckTaskDetails
from .DiskGroupResourceCheckResult import DiskGroupResourceCheckResult as DiskGroupResourceCheckResult
from .DiskResourceCheckResult import DiskResourceCheckResult as DiskResourceCheckResult
from .EntityCompatibilityResult import EntityCompatibilityResult as EntityCompatibilityResult
from .EntityResourceCheckDetails import EntityResourceCheckDetails as EntityResourceCheckDetails
from .FaultDomainResourceCheckResult import FaultDomainResourceCheckResult as FaultDomainResourceCheckResult
from .FileServiceConfig import FileServiceConfig as FileServiceConfig
from .FileServiceConfigOpType import FileServiceConfigOpType as FileServiceConfigOpType
from .FileServiceDomain import FileServiceDomain as FileServiceDomain
from .FileServiceDomainConfig import FileServiceDomainConfig as FileServiceDomainConfig
from .FileServiceDomainQuerySpec import FileServiceDomainQuerySpec as FileServiceDomainQuerySpec
from .FileServiceIpConfig import FileServiceIpConfig as FileServiceIpConfig
from .FileServicePreflightCheckScope import FileServicePreflightCheckScope as FileServicePreflightCheckScope
from .FileServiceVMStatus import FileServiceVMStatus as FileServiceVMStatus
from .FileShare import FileShare as FileShare
from .FileShareAccessType import FileShareAccessType as FileShareAccessType
from .FileShareConfig import FileShareConfig as FileShareConfig
from .FileShareManagingEntity import FileShareManagingEntity as FileShareManagingEntity
from .FileShareNetPermission import FileShareNetPermission as FileShareNetPermission
from .FileShareNfsSecType import FileShareNfsSecType as FileShareNfsSecType
from .FileShareProtocol import FileShareProtocol as FileShareProtocol
from .FileShareQueryProperties import FileShareQueryProperties as FileShareQueryProperties
from .FileShareQueryResult import FileShareQueryResult as FileShareQueryResult
from .FileShareQuerySpec import FileShareQuerySpec as FileShareQuerySpec
from .FileShareRuntimeInfo import FileShareRuntimeInfo as FileShareRuntimeInfo
from .FileShareSmbEncryptionType import FileShareSmbEncryptionType as FileShareSmbEncryptionType
from .FileShareSmbOptions import FileShareSmbOptions as FileShareSmbOptions
from .FileShareSnapshot import FileShareSnapshot as FileShareSnapshot
from .FileShareSnapshotConfig import FileShareSnapshotConfig as FileShareSnapshotConfig
from .FileShareSnapshotQueryResult import FileShareSnapshotQueryResult as FileShareSnapshotQueryResult
from .FileShareSnapshotQuerySpec import FileShareSnapshotQuerySpec as FileShareSnapshotQuerySpec
from .HciMeshClientOperation import HciMeshClientOperation as HciMeshClientOperation
from .HciMeshDatastoreSource import HciMeshDatastoreSource as HciMeshDatastoreSource
from .HostResourceCheckResult import HostResourceCheckResult as HostResourceCheckResult
from .IODiagnosticsFailedCheck import IODiagnosticsFailedCheck as IODiagnosticsFailedCheck
from .IODiagnosticsFailedCheckType import IODiagnosticsFailedCheckType as IODiagnosticsFailedCheckType
from .IODiagnosticsInstance import IODiagnosticsInstance as IODiagnosticsInstance
from .IODiagnosticsInstanceEvent import IODiagnosticsInstanceEvent as IODiagnosticsInstanceEvent
from .IODiagnosticsInstanceEventType import IODiagnosticsInstanceEventType as IODiagnosticsInstanceEventType
from .IODiagnosticsInstanceQuerySpec import IODiagnosticsInstanceQuerySpec as IODiagnosticsInstanceQuerySpec
from .IODiagnosticsInstanceState import IODiagnosticsInstanceState as IODiagnosticsInstanceState
from .IODiagnosticsObjectLayout import IODiagnosticsObjectLayout as IODiagnosticsObjectLayout
from .IODiagnosticsPrecheckResult import IODiagnosticsPrecheckResult as IODiagnosticsPrecheckResult
from .IODiagnosticsStats import IODiagnosticsStats as IODiagnosticsStats
from .IODiagnosticsTarget import IODiagnosticsTarget as IODiagnosticsTarget
from .IODiagnosticsTargetStats import IODiagnosticsTargetStats as IODiagnosticsTargetStats
from .IODiagnosticsTargetType import IODiagnosticsTargetType as IODiagnosticsTargetType
from .IOLatency import IOLatency as IOLatency
from .IOLatencyMetrics import IOLatencyMetrics as IOLatencyMetrics
from .IOLatencyType import IOLatencyType as IOLatencyType
from .LifecycleCheckOperation import LifecycleCheckOperation as LifecycleCheckOperation
from .LifecycleClusterType import LifecycleClusterType as LifecycleClusterType
from .LifecycleConfigDetails import LifecycleConfigDetails as LifecycleConfigDetails
from .LifecycleFaultDomainDetails import LifecycleFaultDomainDetails as LifecycleFaultDomainDetails
from .LifecyclePreCheckResult import LifecyclePreCheckResult as LifecyclePreCheckResult
from .LifecyclePreCheckType import LifecyclePreCheckType as LifecyclePreCheckType
from .LifecycleWitnessDetails import LifecycleWitnessDetails as LifecycleWitnessDetails
from .MetricProfile import MetricProfile as MetricProfile
from .MetricsConfig import MetricsConfig as MetricsConfig
from .Mode import Mode as Mode
from .MountPrecheckItem import MountPrecheckItem as MountPrecheckItem
from .MountPrecheckNetworkConnectivity import MountPrecheckNetworkConnectivity as MountPrecheckNetworkConnectivity
from .MountPrecheckNetworkConnectivityDetail import MountPrecheckNetworkConnectivityDetail as MountPrecheckNetworkConnectivityDetail
from .MountPrecheckNetworkConnectivityResult import MountPrecheckNetworkConnectivityResult as MountPrecheckNetworkConnectivityResult
from .MountPrecheckNetworkLatency import MountPrecheckNetworkLatency as MountPrecheckNetworkLatency
from .MountPrecheckNetworkLatencyDetail import MountPrecheckNetworkLatencyDetail as MountPrecheckNetworkLatencyDetail
from .MountPrecheckNetworkLatencyResult import MountPrecheckNetworkLatencyResult as MountPrecheckNetworkLatencyResult
from .MountPrecheckResult import MountPrecheckResult as MountPrecheckResult
from .MountPrecheckType import MountPrecheckType as MountPrecheckType
from .ObjectHealthTelemetrySummary import ObjectHealthTelemetrySummary as ObjectHealthTelemetrySummary
from .ObjectIOStats import ObjectIOStats as ObjectIOStats
from .PerfsvcRemediateAction import PerfsvcRemediateAction as PerfsvcRemediateAction
from .PrecheckDatastoreSourceOperation import PrecheckDatastoreSourceOperation as PrecheckDatastoreSourceOperation
from .ProactiveRebalanceInfo import ProactiveRebalanceInfo as ProactiveRebalanceInfo
from .RdmaConfig import RdmaConfig as RdmaConfig
from .ReconfigSpec import ReconfigSpec as ReconfigSpec
from .RemoteVcInfo import RemoteVcInfo as RemoteVcInfo
from .RemoteVcInfoStandalone import RemoteVcInfoStandalone as RemoteVcInfoStandalone
from .RemoteVcLinkType import RemoteVcLinkType as RemoteVcLinkType
from .RemoteVsanNetworkTopology import RemoteVsanNetworkTopology as RemoteVsanNetworkTopology
from .RemoteVsanSite import RemoteVsanSite as RemoteVsanSite
from .RemoteVsanSiteAffinity import RemoteVsanSiteAffinity as RemoteVsanSiteAffinity
from .RepairTimerInfo import RepairTimerInfo as RepairTimerInfo
from .ResourceCheckComponentResult import ResourceCheckComponentResult as ResourceCheckComponentResult
from .ResourceCheckComponentType import ResourceCheckComponentType as ResourceCheckComponentType
from .ResourceCheckDataPersistenceResult import ResourceCheckDataPersistenceResult as ResourceCheckDataPersistenceResult
from .ResourceCheckResult import ResourceCheckResult as ResourceCheckResult
from .ResourceCheckSpec import ResourceCheckSpec as ResourceCheckSpec
from .ResourceCheckStatus import ResourceCheckStatus as ResourceCheckStatus
from .ResourceCheckStatusType import ResourceCheckStatusType as ResourceCheckStatusType
from .ResourceCheckTaskDetails import ResourceCheckTaskDetails as ResourceCheckTaskDetails
from .ResourceCheckVsanResult import ResourceCheckVsanResult as ResourceCheckVsanResult
from .ResyncIopsInfo import ResyncIopsInfo as ResyncIopsInfo
from .RuntimeStatsHostMap import RuntimeStatsHostMap as RuntimeStatsHostMap
from .SSDEnduranceThresholdSpec import SSDEnduranceThresholdSpec as SSDEnduranceThresholdSpec
from .ServerHostUnicastInfo import ServerHostUnicastInfo as ServerHostUnicastInfo
from .SharedWitnessCompatibilityResult import SharedWitnessCompatibilityResult as SharedWitnessCompatibilityResult
from .SnapServiceConfig import SnapServiceConfig as SnapServiceConfig
from .SnapshotCreator import SnapshotCreator as SnapshotCreator
from .SnapshotType import SnapshotType as SnapshotType
from .StoragePoolDiskResourceCheckResult import StoragePoolDiskResourceCheckResult as StoragePoolDiskResourceCheckResult
from .StoragePoolResourceCheckResult import StoragePoolResourceCheckResult as StoragePoolResourceCheckResult
from .VcRemoteVsanServerClusterConfig import VcRemoteVsanServerClusterConfig as VcRemoteVsanServerClusterConfig
from .VcRemoteVsanServerClusterInfo import VcRemoteVsanServerClusterInfo as VcRemoteVsanServerClusterInfo
from .VipConfig import VipConfig as VipConfig
from .VipConfigSpec import VipConfigSpec as VipConfigSpec
from .VipDVswitchConfig import VipDVswitchConfig as VipDVswitchConfig
from .VipNetworkConfig import VipNetworkConfig as VipNetworkConfig
from .VipVswitchConfig import VipVswitchConfig as VipVswitchConfig
from .VsanAnalyticsEventLocationType import VsanAnalyticsEventLocationType as VsanAnalyticsEventLocationType
from .VsanAnalyticsEventSnapshotType import VsanAnalyticsEventSnapshotType as VsanAnalyticsEventSnapshotType
from .VsanAnalyticsEventType import VsanAnalyticsEventType as VsanAnalyticsEventType
from .VsanBurnInTest import VsanBurnInTest as VsanBurnInTest
from .VsanBurnInTestCheckResult import VsanBurnInTestCheckResult as VsanBurnInTestCheckResult
from .VsanCloudHealthStatus import VsanCloudHealthStatus as VsanCloudHealthStatus
from .VsanClusterBurnInTestResultList import VsanClusterBurnInTestResultList as VsanClusterBurnInTestResultList
from .VsanCompliantDriver import VsanCompliantDriver as VsanCompliantDriver
from .VsanCompliantFirmware import VsanCompliantFirmware as VsanCompliantFirmware
from .VsanConfigBaseIssue import VsanConfigBaseIssue as VsanConfigBaseIssue
from .VsanConfigCheckResult import VsanConfigCheckResult as VsanConfigCheckResult
from .VsanConfigNotAllDisksClaimedIssue import VsanConfigNotAllDisksClaimedIssue as VsanConfigNotAllDisksClaimedIssue
from .VsanConfigType import VsanConfigType as VsanConfigType
from .VsanDatastoreDefaultPolicySelectionConfig import VsanDatastoreDefaultPolicySelectionConfig as VsanDatastoreDefaultPolicySelectionConfig
from .VsanDeconvergedNetConfig import VsanDeconvergedNetConfig as VsanDeconvergedNetConfig
from .VsanDiskCompatibilityType import VsanDiskCompatibilityType as VsanDiskCompatibilityType
from .VsanDiskModelInfo import VsanDiskModelInfo as VsanDiskModelInfo
from .VsanDownloadItem import VsanDownloadItem as VsanDownloadItem
from .VsanEsaConfig import VsanEsaConfig as VsanEsaConfig
from .VsanEsaConfigInfo import VsanEsaConfigInfo as VsanEsaConfigInfo
from .VsanEsaDiskConfiguration import VsanEsaDiskConfiguration as VsanEsaDiskConfiguration
from .VsanExtendedConfig import VsanExtendedConfig as VsanExtendedConfig
from .VsanFileServiceOvfSpec import VsanFileServiceOvfSpec as VsanFileServiceOvfSpec
from .VsanFileServicePreflightCheckResult import VsanFileServicePreflightCheckResult as VsanFileServicePreflightCheckResult
from .VsanFileServiceSystem import VsanFileServiceSystem as VsanFileServiceSystem
from .VsanGenericClusterBaseIssue import VsanGenericClusterBaseIssue as VsanGenericClusterBaseIssue
from .VsanGenericClusterBestPracticeHealth import VsanGenericClusterBestPracticeHealth as VsanGenericClusterBestPracticeHealth
from .VsanHclDeviceConstraint import VsanHclDeviceConstraint as VsanHclDeviceConstraint
from .VsanHclDiskConstraint import VsanHclDiskConstraint as VsanHclDiskConstraint
from .VsanHclDriverInfo import VsanHclDriverInfo as VsanHclDriverInfo
from .VsanHclMinFwConstraint import VsanHclMinFwConstraint as VsanHclMinFwConstraint
from .VsanHclQuerySpec import VsanHclQuerySpec as VsanHclQuerySpec
from .VsanHclReleaseConstraint import VsanHclReleaseConstraint as VsanHclReleaseConstraint
from .VsanHealthConfigSpec import VsanHealthConfigSpec as VsanHealthConfigSpec
from .VsanHealthCustomizationSpec import VsanHealthCustomizationSpec as VsanHealthCustomizationSpec
from .VsanHealthPerspective import VsanHealthPerspective as VsanHealthPerspective
from .VsanHealthPerspective90 import VsanHealthPerspective90 as VsanHealthPerspective90
from .VsanHealthStatusType import VsanHealthStatusType as VsanHealthStatusType
from .VsanHealthThreshold import VsanHealthThreshold as VsanHealthThreshold
from .VsanHealthThresholdTarget import VsanHealthThresholdTarget as VsanHealthThresholdTarget
from .VsanHistoricalHealthConfig import VsanHistoricalHealthConfig as VsanHistoricalHealthConfig
from .VsanHostDeviceInfo import VsanHostDeviceInfo as VsanHostDeviceInfo
from .VsanHostVdsSystem import VsanHostVdsSystem as VsanHostVdsSystem
from .VsanHwToVcgInfoMappingSpec import VsanHwToVcgInfoMappingSpec as VsanHwToVcgInfoMappingSpec
from .VsanIOTripAnalyzerConfig import VsanIOTripAnalyzerConfig as VsanIOTripAnalyzerConfig
from .VsanIOTripAnalyzerRecurrence import VsanIOTripAnalyzerRecurrence as VsanIOTripAnalyzerRecurrence
from .VsanIOTripAnalyzerRecurrenceStatus import VsanIOTripAnalyzerRecurrenceStatus as VsanIOTripAnalyzerRecurrenceStatus
from .VsanInternalExtendedConfig import VsanInternalExtendedConfig as VsanInternalExtendedConfig
from .VsanNetworkConfigBaseIssue import VsanNetworkConfigBaseIssue as VsanNetworkConfigBaseIssue
from .VsanNetworkConfigBestPracticeHealth import VsanNetworkConfigBestPracticeHealth as VsanNetworkConfigBestPracticeHealth
from .VsanNetworkConfigPnicSpeedInconsistencyIssue import VsanNetworkConfigPnicSpeedInconsistencyIssue as VsanNetworkConfigPnicSpeedInconsistencyIssue
from .VsanNetworkConfigPortgroupWithNoRedundancyIssue import VsanNetworkConfigPortgroupWithNoRedundancyIssue as VsanNetworkConfigPortgroupWithNoRedundancyIssue
from .VsanNetworkConfigVdsScopeIssue import VsanNetworkConfigVdsScopeIssue as VsanNetworkConfigVdsScopeIssue
from .VsanNetworkConfigVsanNotOnVdsIssue import VsanNetworkConfigVsanNotOnVdsIssue as VsanNetworkConfigVsanNotOnVdsIssue
from .VsanNetworkConfigVswitchWithNoRedundancyIssue import VsanNetworkConfigVswitchWithNoRedundancyIssue as VsanNetworkConfigVswitchWithNoRedundancyIssue
from .VsanNetworkVMotionVmknicNotFountIssue import VsanNetworkVMotionVmknicNotFountIssue as VsanNetworkVMotionVmknicNotFountIssue
from .VsanObjSnapParams import VsanObjSnapParams as VsanObjSnapParams
from .VsanObjectDetail import VsanObjectDetail as VsanObjectDetail
from .VsanObjectManager import VsanObjectManager as VsanObjectManager
from .VsanObjectSnapshotId import VsanObjectSnapshotId as VsanObjectSnapshotId
from .VsanPMemConfig import VsanPMemConfig as VsanPMemConfig
from .VsanPerfsvcHealthResult import VsanPerfsvcHealthResult as VsanPerfsvcHealthResult
from .VsanPolicyManager import VsanPolicyManager as VsanPolicyManager
from .VsanPolicyRegulationCheckOpEnum import VsanPolicyRegulationCheckOpEnum as VsanPolicyRegulationCheckOpEnum
from .VsanPrepareVsanForVcsaSpec import VsanPrepareVsanForVcsaSpec as VsanPrepareVsanForVcsaSpec
from .VsanResourceCheckSystem import VsanResourceCheckSystem as VsanResourceCheckSystem
from .VsanServiceStatus import VsanServiceStatus as VsanServiceStatus
from .VsanSiteLocationType import VsanSiteLocationType as VsanSiteLocationType
from .VsanSnapHealthType import VsanSnapHealthType as VsanSnapHealthType
from .VsanSnapStatsExpirationType import VsanSnapStatsExpirationType as VsanSnapStatsExpirationType
from .VsanSnapVmMembershipChangeStatus import VsanSnapVmMembershipChangeStatus as VsanSnapVmMembershipChangeStatus
from .VsanSnapshotDetail import VsanSnapshotDetail as VsanSnapshotDetail
from .VsanSnapshotQueryResult import VsanSnapshotQueryResult as VsanSnapshotQueryResult
from .VsanSnapshotQuerySpec import VsanSnapshotQuerySpec as VsanSnapshotQuerySpec
from .VsanSpaceEfficiencyMetadataSize import VsanSpaceEfficiencyMetadataSize as VsanSpaceEfficiencyMetadataSize
from .VsanSpaceEfficiencyRatio import VsanSpaceEfficiencyRatio as VsanSpaceEfficiencyRatio
from .VsanSyncReason import VsanSyncReason as VsanSyncReason
from .VsanSyncStatus import VsanSyncStatus as VsanSyncStatus
from .VsanUnmapConfig import VsanUnmapConfig as VsanUnmapConfig
from .VsanUpdateItem import VsanUpdateItem as VsanUpdateItem
from .VsanUpdateItemImpactType import VsanUpdateItemImpactType as VsanUpdateItemImpactType
from .VsanUpdateItemType import VsanUpdateItemType as VsanUpdateItemType
from .VsanVcPostDeployConfigSpec import VsanVcPostDeployConfigSpec as VsanVcPostDeployConfigSpec
from .VsanVcStretchedClusterConfigSpec import VsanVcStretchedClusterConfigSpec as VsanVcStretchedClusterConfigSpec
from .VsanVcsaDeploymentPhase import VsanVcsaDeploymentPhase as VsanVcsaDeploymentPhase
from .VsanVcsaDeploymentProgress import VsanVcsaDeploymentProgress as VsanVcsaDeploymentProgress
from .VsanVdsMigrationPlan import VsanVdsMigrationPlan as VsanVdsMigrationPlan
from .VsanVdsPgMigrationHostInfo import VsanVdsPgMigrationHostInfo as VsanVdsPgMigrationHostInfo
from .VsanVdsPgMigrationSpec import VsanVdsPgMigrationSpec as VsanVdsPgMigrationSpec
from .VsanVdsPgMigrationVmInfo import VsanVdsPgMigrationVmInfo as VsanVdsPgMigrationVmInfo
from .VsanVdsSystem import VsanVdsSystem as VsanVdsSystem
from .VsanVibInstallPreflightStatus import VsanVibInstallPreflightStatus as VsanVibInstallPreflightStatus
from .VsanVibScanResult import VsanVibScanResult as VsanVibScanResult
from .VsanVibSpec import VsanVibSpec as VsanVibSpec
from .VsanVibType import VsanVibType as VsanVibType
from .VsanVmVdsMigrationSpec import VsanVmVdsMigrationSpec as VsanVmVdsMigrationSpec
from .VsanVnicVdsMigrationSpec import VsanVnicVdsMigrationSpec as VsanVnicVdsMigrationSpec
from .VsanVumConfig import VsanVumConfig as VsanVumConfig
from .WitnessHostConfig import WitnessHostConfig as WitnessHostConfig
from .XVCClientInfo import XVCClientInfo as XVCClientInfo
from .XVCDatastoreConfig import XVCDatastoreConfig as XVCDatastoreConfig
from .XVCDatastoreInfo import XVCDatastoreInfo as XVCDatastoreInfo
from .XvcClientConfig import XvcClientConfig as XvcClientConfig
from .XvcClientInfoSpec import XvcClientInfoSpec as XvcClientInfoSpec
from .XvcQueryCriteria import XvcQueryCriteria as XvcQueryCriteria
from .XvcQueryCriteriaOperator import XvcQueryCriteriaOperator as XvcQueryCriteriaOperator
from .XvcQueryFilter import XvcQueryFilter as XvcQueryFilter
from .XvcQueryFilterOperator import XvcQueryFilterOperator as XvcQueryFilterOperator
from .XvcQueryPropertyValue import XvcQueryPropertyValue as XvcQueryPropertyValue
from .XvcQueryResultSet import XvcQueryResultSet as XvcQueryResultSet
from .XvcQuerySpec import XvcQuerySpec as XvcQuerySpec
from .XvcResultItem import XvcResultItem as XvcResultItem
from .clusterPowerState import clusterPowerState as clusterPowerState



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import AboutInfo
from pyVmomi.vim import Datastore
from pyVmomi.vim import Folder
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Network
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.host import ConnectInfo
from pyVmomi.vim.host import ConnectSpec

from pyVmomi.vim.option import OptionValue

from pyVmomi.vim.vm import ConfigOptionDescriptor

class Datacenter(ManagedEntity):
   class BasicConnectInfo(DynamicData):
      hostname: Optional[str] = None
      error: Optional[MethodFault] = None
      serverIp: Optional[str] = None
      numVm: Optional[int] = None
      numPoweredOnVm: Optional[int] = None
      hostProductInfo: Optional[AboutInfo] = None
      hardwareVendor: Optional[str] = None
      hardwareModel: Optional[str] = None

   class ConfigInfo(DynamicData):
      defaultHardwareVersionKey: Optional[str] = None
      maximumHardwareVersionKey: Optional[str] = None

   class ConfigSpec(DynamicData):
      defaultHardwareVersionKey: Optional[str] = None
      maximumHardwareVersionKey: Optional[str] = None

   @property
   def vmFolder(self) -> Folder: ...
   @property
   def hostFolder(self) -> Folder: ...
   @property
   def datastoreFolder(self) -> Folder: ...
   @property
   def networkFolder(self) -> Folder: ...
   @property
   def datastore(self) -> list[Datastore]: ...
   @property
   def network(self) -> list[Network]: ...
   @property
   def configuration(self) -> ConfigInfo: ...

   def BatchQueryConnectInfo(self, hostSpecs: list[ConnectSpec]) -> list[BasicConnectInfo]: ...
   def QueryConnectionInfo(self, hostname: str, port: int, username: str, password: str, sslThumbprint: Optional[str], sslCertificate: Optional[str]) -> ConnectInfo: ...
   def QueryConnectionInfoViaSpec(self, spec: ConnectSpec) -> ConnectInfo: ...
   def PowerOnVm(self, vm: list[VirtualMachine], option: list[OptionValue]) -> Task: ...
   def QueryConfigOptionDescriptor(self) -> list[ConfigOptionDescriptor]: ...
   def Reconfigure(self, spec: ConfigSpec, modify: bool) -> Task: ...
